// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_MEMOP_IMMEDIATE_512_LDRSB_A32_H_
#define VIXL_ASSEMBLER_COND_RD_MEMOP_IMMEDIATE_512_LDRSB_A32_H_

const byte kInstruction_ldrsb_pl_r13_r0_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd0, 0x51 // ldrsb pl r13 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r5_r3_plus_0_Offset[] = {
  0xd0, 0x50, 0xd3, 0xa1 // ldrsb ge r5 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r0_r4_plus_0_Offset[] = {
  0xd0, 0x00, 0xd4, 0x31 // ldrsb cc r0 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r0_r0_plus_0_Offset[] = {
  0xd0, 0x00, 0xd0, 0xa1 // ldrsb ge r0 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_eq_r12_r3_plus_0_Offset[] = {
  0xd0, 0xc0, 0xd3, 0x01 // ldrsb eq r12 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r4_r13_plus_0_Offset[] = {
  0xd0, 0x40, 0xdd, 0xe1 // ldrsb al r4 r13 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r8_r2_plus_0_Offset[] = {
  0xd0, 0x80, 0xd2, 0x41 // ldrsb mi r8 r2 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r6_r9_plus_0_Offset[] = {
  0xd0, 0x60, 0xd9, 0x41 // ldrsb mi r6 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r13_r11_plus_0_Offset[] = {
  0xd0, 0xd0, 0xdb, 0xc1 // ldrsb gt r13 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_cs_r0_r7_plus_0_Offset[] = {
  0xd0, 0x00, 0xd7, 0x21 // ldrsb cs r0 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r7_r11_plus_0_Offset[] = {
  0xd0, 0x70, 0xdb, 0xa1 // ldrsb ge r7 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_pl_r11_r12_plus_0_Offset[] = {
  0xd0, 0xb0, 0xdc, 0x51 // ldrsb pl r11 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_cs_r2_r12_plus_0_Offset[] = {
  0xd0, 0x20, 0xdc, 0x21 // ldrsb cs r2 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r2_r14_plus_0_Offset[] = {
  0xd0, 0x20, 0xde, 0x71 // ldrsb vc r2 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r13_r6_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd6, 0xd1 // ldrsb le r13 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r1_r2_plus_0_Offset[] = {
  0xd0, 0x10, 0xd2, 0x91 // ldrsb ls r1 r2 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r1_r6_plus_0_Offset[] = {
  0xd0, 0x10, 0xd6, 0x31 // ldrsb cc r1 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r10_r3_plus_0_Offset[] = {
  0xd0, 0xa0, 0xd3, 0xe1 // ldrsb al r10 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r7_r9_plus_0_Offset[] = {
  0xd0, 0x70, 0xd9, 0xe1 // ldrsb al r7 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r5_r3_plus_0_Offset[] = {
  0xd0, 0x50, 0xd3, 0x61 // ldrsb vs r5 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_pl_r4_r4_plus_0_Offset[] = {
  0xd0, 0x40, 0xd4, 0x51 // ldrsb pl r4 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r11_r9_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd9, 0x11 // ldrsb ne r11 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r7_r14_plus_0_Offset[] = {
  0xd0, 0x70, 0xde, 0x31 // ldrsb cc r7 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r9_r3_plus_0_Offset[] = {
  0xd0, 0x90, 0xd3, 0x11 // ldrsb ne r9 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r6_r14_plus_0_Offset[] = {
  0xd0, 0x60, 0xde, 0x31 // ldrsb cc r6 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r14_r14_plus_0_Offset[] = {
  0xd0, 0xe0, 0xde, 0x11 // ldrsb ne r14 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r13_r14_plus_0_Offset[] = {
  0xd0, 0xd0, 0xde, 0xe1 // ldrsb al r13 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r3_r1_plus_0_Offset[] = {
  0xd0, 0x30, 0xd1, 0x31 // ldrsb cc r3 r1 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r1_r2_plus_0_Offset[] = {
  0xd0, 0x10, 0xd2, 0xa1 // ldrsb ge r1 r2 plus 0 Offset
};
const byte kInstruction_ldrsb_eq_r3_r4_plus_0_Offset[] = {
  0xd0, 0x30, 0xd4, 0x01 // ldrsb eq r3 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r5_r10_plus_0_Offset[] = {
  0xd0, 0x50, 0xda, 0xe1 // ldrsb al r5 r10 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r1_r3_plus_0_Offset[] = {
  0xd0, 0x10, 0xd3, 0x41 // ldrsb mi r1 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r1_r4_plus_0_Offset[] = {
  0xd0, 0x10, 0xd4, 0xc1 // ldrsb gt r1 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r7_r12_plus_0_Offset[] = {
  0xd0, 0x70, 0xdc, 0xe1 // ldrsb al r7 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r14_r2_plus_0_Offset[] = {
  0xd0, 0xe0, 0xd2, 0xa1 // ldrsb ge r14 r2 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r9_r7_plus_0_Offset[] = {
  0xd0, 0x90, 0xd7, 0xd1 // ldrsb le r9 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r9_r14_plus_0_Offset[] = {
  0xd0, 0x90, 0xde, 0xe1 // ldrsb al r9 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_hi_r10_r12_plus_0_Offset[] = {
  0xd0, 0xa0, 0xdc, 0x81 // ldrsb hi r10 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r6_r5_plus_0_Offset[] = {
  0xd0, 0x60, 0xd5, 0xd1 // ldrsb le r6 r5 plus 0 Offset
};
const byte kInstruction_ldrsb_cs_r14_r12_plus_0_Offset[] = {
  0xd0, 0xe0, 0xdc, 0x21 // ldrsb cs r14 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r6_r9_plus_0_Offset[] = {
  0xd0, 0x60, 0xd9, 0x71 // ldrsb vc r6 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r3_r9_plus_0_Offset[] = {
  0xd0, 0x30, 0xd9, 0x11 // ldrsb ne r3 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r2_r9_plus_0_Offset[] = {
  0xd0, 0x20, 0xd9, 0xb1 // ldrsb lt r2 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r5_r11_plus_0_Offset[] = {
  0xd0, 0x50, 0xdb, 0x71 // ldrsb vc r5 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r5_r1_plus_0_Offset[] = {
  0xd0, 0x50, 0xd1, 0xc1 // ldrsb gt r5 r1 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r12_r4_plus_0_Offset[] = {
  0xd0, 0xc0, 0xd4, 0xe1 // ldrsb al r12 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r11_r10_plus_0_Offset[] = {
  0xd0, 0xb0, 0xda, 0x91 // ldrsb ls r11 r10 plus 0 Offset
};
const byte kInstruction_ldrsb_eq_r14_r7_plus_0_Offset[] = {
  0xd0, 0xe0, 0xd7, 0x01 // ldrsb eq r14 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r7_r0_plus_0_Offset[] = {
  0xd0, 0x70, 0xd0, 0x71 // ldrsb vc r7 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r2_r6_plus_0_Offset[] = {
  0xd0, 0x20, 0xd6, 0xd1 // ldrsb le r2 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r2_r6_plus_0_Offset[] = {
  0xd0, 0x20, 0xd6, 0xc1 // ldrsb gt r2 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r6_r6_plus_0_Offset[] = {
  0xd0, 0x60, 0xd6, 0xe1 // ldrsb al r6 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r10_r8_plus_0_Offset[] = {
  0xd0, 0xa0, 0xd8, 0x91 // ldrsb ls r10 r8 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r5_r8_plus_0_Offset[] = {
  0xd0, 0x50, 0xd8, 0xb1 // ldrsb lt r5 r8 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r13_r14_plus_0_Offset[] = {
  0xd0, 0xd0, 0xde, 0x61 // ldrsb vs r13 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r9_r7_plus_0_Offset[] = {
  0xd0, 0x90, 0xd7, 0xc1 // ldrsb gt r9 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r8_r9_plus_0_Offset[] = {
  0xd0, 0x80, 0xd9, 0x31 // ldrsb cc r8 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r2_r7_plus_0_Offset[] = {
  0xd0, 0x20, 0xd7, 0xd1 // ldrsb le r2 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r0_r1_plus_0_Offset[] = {
  0xd0, 0x00, 0xd1, 0xa1 // ldrsb ge r0 r1 plus 0 Offset
};
const byte kInstruction_ldrsb_eq_r10_r14_plus_0_Offset[] = {
  0xd0, 0xa0, 0xde, 0x01 // ldrsb eq r10 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r3_r3_plus_0_Offset[] = {
  0xd0, 0x30, 0xd3, 0x91 // ldrsb ls r3 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r11_r6_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd6, 0x41 // ldrsb mi r11 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r14_r12_plus_0_Offset[] = {
  0xd0, 0xe0, 0xdc, 0x11 // ldrsb ne r14 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r1_r12_plus_0_Offset[] = {
  0xd0, 0x10, 0xdc, 0x61 // ldrsb vs r1 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r0_r0_plus_0_Offset[] = {
  0xd0, 0x00, 0xd0, 0x91 // ldrsb ls r0 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r12_r14_plus_0_Offset[] = {
  0xd0, 0xc0, 0xde, 0xb1 // ldrsb lt r12 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r13_r9_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd9, 0xb1 // ldrsb lt r13 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r13_r9_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd9, 0xa1 // ldrsb ge r13 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_cs_r11_r0_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd0, 0x21 // ldrsb cs r11 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_hi_r13_r11_plus_0_Offset[] = {
  0xd0, 0xd0, 0xdb, 0x81 // ldrsb hi r13 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_cs_r13_r9_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd9, 0x21 // ldrsb cs r13 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r10_r10_plus_0_Offset[] = {
  0xd0, 0xa0, 0xda, 0x11 // ldrsb ne r10 r10 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r13_r9_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd9, 0x71 // ldrsb vc r13 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r9_r3_plus_0_Offset[] = {
  0xd0, 0x90, 0xd3, 0x71 // ldrsb vc r9 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_cc_r10_r4_plus_0_Offset[] = {
  0xd0, 0xa0, 0xd4, 0x31 // ldrsb cc r10 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_hi_r6_r6_plus_0_Offset[] = {
  0xd0, 0x60, 0xd6, 0x81 // ldrsb hi r6 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r11_r1_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd1, 0xd1 // ldrsb le r11 r1 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r3_r5_plus_0_Offset[] = {
  0xd0, 0x30, 0xd5, 0xc1 // ldrsb gt r3 r5 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r0_r10_plus_0_Offset[] = {
  0xd0, 0x00, 0xda, 0xb1 // ldrsb lt r0 r10 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r6_r0_plus_0_Offset[] = {
  0xd0, 0x60, 0xd0, 0x61 // ldrsb vs r6 r0 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r8_r9_plus_0_Offset[] = {
  0xd0, 0x80, 0xd9, 0x61 // ldrsb vs r8 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r9_r7_plus_0_Offset[] = {
  0xd0, 0x90, 0xd7, 0x41 // ldrsb mi r9 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r12_r11_plus_0_Offset[] = {
  0xd0, 0xc0, 0xdb, 0x61 // ldrsb vs r12 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r11_r7_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd7, 0x71 // ldrsb vc r11 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_hi_r11_r5_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd5, 0x81 // ldrsb hi r11 r5 plus 0 Offset
};
const byte kInstruction_ldrsb_lt_r0_r11_plus_0_Offset[] = {
  0xd0, 0x00, 0xdb, 0xb1 // ldrsb lt r0 r11 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r11_r1_plus_0_Offset[] = {
  0xd0, 0xb0, 0xd1, 0x11 // ldrsb ne r11 r1 plus 0 Offset
};
const byte kInstruction_ldrsb_ls_r5_r13_plus_0_Offset[] = {
  0xd0, 0x50, 0xdd, 0x91 // ldrsb ls r5 r13 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r13_r3_plus_0_Offset[] = {
  0xd0, 0xd0, 0xd3, 0xc1 // ldrsb gt r13 r3 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r12_r12_plus_0_Offset[] = {
  0xd0, 0xc0, 0xdc, 0x61 // ldrsb vs r12 r12 plus 0 Offset
};
const byte kInstruction_ldrsb_mi_r12_r7_plus_0_Offset[] = {
  0xd0, 0xc0, 0xd7, 0x41 // ldrsb mi r12 r7 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r3_r4_plus_0_Offset[] = {
  0xd0, 0x30, 0xd4, 0xd1 // ldrsb le r3 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r11_r10_plus_0_Offset[] = {
  0xd0, 0xb0, 0xda, 0x11 // ldrsb ne r11 r10 plus 0 Offset
};
const byte kInstruction_ldrsb_gt_r6_r13_plus_0_Offset[] = {
  0xd0, 0x60, 0xdd, 0xc1 // ldrsb gt r6 r13 plus 0 Offset
};
const byte kInstruction_ldrsb_hi_r4_r8_plus_0_Offset[] = {
  0xd0, 0x40, 0xd8, 0x81 // ldrsb hi r4 r8 plus 0 Offset
};
const byte kInstruction_ldrsb_ge_r14_r5_plus_0_Offset[] = {
  0xd0, 0xe0, 0xd5, 0xa1 // ldrsb ge r14 r5 plus 0 Offset
};
const byte kInstruction_ldrsb_vc_r9_r6_plus_0_Offset[] = {
  0xd0, 0x90, 0xd6, 0x71 // ldrsb vc r9 r6 plus 0 Offset
};
const byte kInstruction_ldrsb_le_r2_r9_plus_0_Offset[] = {
  0xd0, 0x20, 0xd9, 0xd1 // ldrsb le r2 r9 plus 0 Offset
};
const byte kInstruction_ldrsb_ne_r10_r4_plus_0_Offset[] = {
  0xd0, 0xa0, 0xd4, 0x11 // ldrsb ne r10 r4 plus 0 Offset
};
const byte kInstruction_ldrsb_vs_r10_r14_plus_0_Offset[] = {
  0xd0, 0xa0, 0xde, 0x61 // ldrsb vs r10 r14 plus 0 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_40_Offset[] = {
  0xd8, 0x02, 0x5b, 0xe1 // ldrsb al r0 r11 minus 40 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_169_Offset[] = {
  0xd9, 0x0a, 0xd9, 0xe1 // ldrsb al r0 r9 plus 169 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_45_Offset[] = {
  0xdd, 0x02, 0xd9, 0xe1 // ldrsb al r0 r9 plus 45 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_minus_237_Offset[] = {
  0xdd, 0x0e, 0x5e, 0xe1 // ldrsb al r0 r14 minus 237 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_145_Offset[] = {
  0xd1, 0x09, 0x5b, 0xe1 // ldrsb al r0 r11 minus 145 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_plus_69_Offset[] = {
  0xd5, 0x04, 0xdd, 0xe1 // ldrsb al r0 r13 plus 69 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_minus_37_Offset[] = {
  0xd5, 0x02, 0x58, 0xe1 // ldrsb al r0 r8 minus 37 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_minus_16_Offset[] = {
  0xd0, 0x01, 0x59, 0xe1 // ldrsb al r0 r9 minus 16 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_89_Offset[] = {
  0xd9, 0x05, 0x5d, 0xe1 // ldrsb al r0 r13 minus 89 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_174_Offset[] = {
  0xde, 0x0a, 0xde, 0xe1 // ldrsb al r0 r14 plus 174 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_177_Offset[] = {
  0xd1, 0x0b, 0x55, 0xe1 // ldrsb al r0 r5 minus 177 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_10_Offset[] = {
  0xda, 0x00, 0xd0, 0xe1 // ldrsb al r0 r0 plus 10 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_80_Offset[] = {
  0xd0, 0x05, 0xd0, 0xe1 // ldrsb al r0 r0 plus 80 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_minus_239_Offset[] = {
  0xdf, 0x0e, 0x56, 0xe1 // ldrsb al r0 r6 minus 239 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_146_Offset[] = {
  0xd2, 0x09, 0x54, 0xe1 // ldrsb al r0 r4 minus 146 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_minus_222_Offset[] = {
  0xde, 0x0d, 0x5c, 0xe1 // ldrsb al r0 r12 minus 222 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_212_Offset[] = {
  0xd4, 0x0d, 0xd1, 0xe1 // ldrsb al r0 r1 plus 212 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_plus_236_Offset[] = {
  0xdc, 0x0e, 0xd6, 0xe1 // ldrsb al r0 r6 plus 236 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_46_Offset[] = {
  0xde, 0x02, 0x5b, 0xe1 // ldrsb al r0 r11 minus 46 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_minus_117_Offset[] = {
  0xd5, 0x07, 0x59, 0xe1 // ldrsb al r0 r9 minus 117 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_152_Offset[] = {
  0xd8, 0x09, 0x55, 0xe1 // ldrsb al r0 r5 minus 152 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_240_Offset[] = {
  0xd0, 0x0f, 0xd2, 0xe1 // ldrsb al r0 r2 plus 240 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_20_Offset[] = {
  0xd4, 0x01, 0x50, 0xe1 // ldrsb al r0 r0 minus 20 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_200_Offset[] = {
  0xd8, 0x0c, 0x5d, 0xe1 // ldrsb al r0 r13 minus 200 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_106_Offset[] = {
  0xda, 0x06, 0xde, 0xe1 // ldrsb al r0 r14 plus 106 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_235_Offset[] = {
  0xdb, 0x0e, 0x54, 0xe1 // ldrsb al r0 r4 minus 235 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_plus_188_Offset[] = {
  0xdc, 0x0b, 0xdb, 0xe1 // ldrsb al r0 r11 plus 188 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_224_Offset[] = {
  0xd0, 0x0e, 0xd5, 0xe1 // ldrsb al r0 r5 plus 224 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_minus_218_Offset[] = {
  0xda, 0x0d, 0x5a, 0xe1 // ldrsb al r0 r10 minus 218 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_132_Offset[] = {
  0xd4, 0x08, 0xd4, 0xe1 // ldrsb al r0 r4 plus 132 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_plus_210_Offset[] = {
  0xd2, 0x0d, 0xdc, 0xe1 // ldrsb al r0 r12 plus 210 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_24_Offset[] = {
  0xd8, 0x01, 0xd7, 0xe1 // ldrsb al r0 r7 plus 24 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_71_Offset[] = {
  0xd7, 0x04, 0xd9, 0xe1 // ldrsb al r0 r9 plus 71 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_241_Offset[] = {
  0xd1, 0x0f, 0x5b, 0xe1 // ldrsb al r0 r11 minus 241 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_77_Offset[] = {
  0xdd, 0x04, 0x55, 0xe1 // ldrsb al r0 r5 minus 77 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_159_Offset[] = {
  0xdf, 0x09, 0xd7, 0xe1 // ldrsb al r0 r7 plus 159 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_191_Offset[] = {
  0xdf, 0x0b, 0xd0, 0xe1 // ldrsb al r0 r0 plus 191 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_162_Offset[] = {
  0xd2, 0x0a, 0x52, 0xe1 // ldrsb al r0 r2 minus 162 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_102_Offset[] = {
  0xd6, 0x06, 0xd4, 0xe1 // ldrsb al r0 r4 plus 102 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_91_Offset[] = {
  0xdb, 0x05, 0x53, 0xe1 // ldrsb al r0 r3 minus 91 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_67_Offset[] = {
  0xd3, 0x04, 0xde, 0xe1 // ldrsb al r0 r14 plus 67 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_209_Offset[] = {
  0xd1, 0x0d, 0xd2, 0xe1 // ldrsb al r0 r2 plus 209 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_220_Offset[] = {
  0xdc, 0x0d, 0x5d, 0xe1 // ldrsb al r0 r13 minus 220 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_minus_112_Offset[] = {
  0xd0, 0x07, 0x59, 0xe1 // ldrsb al r0 r9 minus 112 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_95_Offset[] = {
  0xdf, 0x05, 0x54, 0xe1 // ldrsb al r0 r4 minus 95 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_minus_133_Offset[] = {
  0xd5, 0x08, 0x5e, 0xe1 // ldrsb al r0 r14 minus 133 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_70_Offset[] = {
  0xd6, 0x04, 0xd3, 0xe1 // ldrsb al r0 r3 plus 70 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_191_Offset[] = {
  0xdf, 0x0b, 0x55, 0xe1 // ldrsb al r0 r5 minus 191 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_minus_10_Offset[] = {
  0xda, 0x00, 0x57, 0xe1 // ldrsb al r0 r7 minus 10 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_plus_10_Offset[] = {
  0xda, 0x00, 0xda, 0xe1 // ldrsb al r0 r10 plus 10 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_78_Offset[] = {
  0xde, 0x04, 0xd5, 0xe1 // ldrsb al r0 r5 plus 78 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_252_Offset[] = {
  0xdc, 0x0f, 0xd2, 0xe1 // ldrsb al r0 r2 plus 252 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_plus_150_Offset[] = {
  0xd6, 0x09, 0xdc, 0xe1 // ldrsb al r0 r12 plus 150 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_69_Offset[] = {
  0xd5, 0x04, 0x5d, 0xe1 // ldrsb al r0 r13 minus 69 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_12_Offset[] = {
  0xdc, 0x00, 0x55, 0xe1 // ldrsb al r0 r5 minus 12 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_115_Offset[] = {
  0xd3, 0x07, 0x50, 0xe1 // ldrsb al r0 r0 minus 115 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_233_Offset[] = {
  0xd9, 0x0e, 0x55, 0xe1 // ldrsb al r0 r5 minus 233 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_plus_214_Offset[] = {
  0xd6, 0x0d, 0xda, 0xe1 // ldrsb al r0 r10 plus 214 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_123_Offset[] = {
  0xdb, 0x07, 0xd4, 0xe1 // ldrsb al r0 r4 plus 123 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_plus_121_Offset[] = {
  0xd9, 0x07, 0xdc, 0xe1 // ldrsb al r0 r12 plus 121 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_93_Offset[] = {
  0xdd, 0x05, 0xd3, 0xe1 // ldrsb al r0 r3 plus 93 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_239_Offset[] = {
  0xdf, 0x0e, 0xd5, 0xe1 // ldrsb al r0 r5 plus 239 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_56_Offset[] = {
  0xd8, 0x03, 0x5d, 0xe1 // ldrsb al r0 r13 minus 56 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_1_Offset[] = {
  0xd1, 0x00, 0x54, 0xe1 // ldrsb al r0 r4 minus 1 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_plus_190_Offset[] = {
  0xde, 0x0b, 0xd6, 0xe1 // ldrsb al r0 r6 plus 190 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_plus_232_Offset[] = {
  0xd8, 0x0e, 0xda, 0xe1 // ldrsb al r0 r10 plus 232 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_232_Offset[] = {
  0xd8, 0x0e, 0xd1, 0xe1 // ldrsb al r0 r1 plus 232 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_210_Offset[] = {
  0xd2, 0x0d, 0xde, 0xe1 // ldrsb al r0 r14 plus 210 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_208_Offset[] = {
  0xd0, 0x0d, 0xd3, 0xe1 // ldrsb al r0 r3 plus 208 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_221_Offset[] = {
  0xdd, 0x0d, 0xd0, 0xe1 // ldrsb al r0 r0 plus 221 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_77_Offset[] = {
  0xdd, 0x04, 0x52, 0xe1 // ldrsb al r0 r2 minus 77 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_plus_142_Offset[] = {
  0xde, 0x08, 0xda, 0xe1 // ldrsb al r0 r10 plus 142 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_14_Offset[] = {
  0xde, 0x00, 0xd7, 0xe1 // ldrsb al r0 r7 plus 14 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_29_Offset[] = {
  0xdd, 0x01, 0x5d, 0xe1 // ldrsb al r0 r13 minus 29 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_plus_165_Offset[] = {
  0xd5, 0x0a, 0xdd, 0xe1 // ldrsb al r0 r13 plus 165 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_minus_245_Offset[] = {
  0xd5, 0x0f, 0x5c, 0xe1 // ldrsb al r0 r12 minus 245 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_minus_199_Offset[] = {
  0xd7, 0x0c, 0x58, 0xe1 // ldrsb al r0 r8 minus 199 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_minus_34_Offset[] = {
  0xd2, 0x02, 0x59, 0xe1 // ldrsb al r0 r9 minus 34 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_182_Offset[] = {
  0xd6, 0x0b, 0xd5, 0xe1 // ldrsb al r0 r5 plus 182 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_70_Offset[] = {
  0xd6, 0x04, 0x5d, 0xe1 // ldrsb al r0 r13 minus 70 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_241_Offset[] = {
  0xd1, 0x0f, 0x53, 0xe1 // ldrsb al r0 r3 minus 241 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_134_Offset[] = {
  0xd6, 0x08, 0xd4, 0xe1 // ldrsb al r0 r4 plus 134 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_minus_155_Offset[] = {
  0xdb, 0x09, 0x56, 0xe1 // ldrsb al r0 r6 minus 155 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_105_Offset[] = {
  0xd9, 0x06, 0xd2, 0xe1 // ldrsb al r0 r2 plus 105 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_29_Offset[] = {
  0xdd, 0x01, 0xd9, 0xe1 // ldrsb al r0 r9 plus 29 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_minus_223_Offset[] = {
  0xdf, 0x0d, 0x51, 0xe1 // ldrsb al r0 r1 minus 223 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_minus_141_Offset[] = {
  0xdd, 0x08, 0x5a, 0xe1 // ldrsb al r0 r10 minus 141 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_15_Offset[] = {
  0xdf, 0x00, 0xd4, 0xe1 // ldrsb al r0 r4 plus 15 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_157_Offset[] = {
  0xdd, 0x09, 0xd2, 0xe1 // ldrsb al r0 r2 plus 157 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_minus_122_Offset[] = {
  0xda, 0x07, 0x5a, 0xe1 // ldrsb al r0 r10 minus 122 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_54_Offset[] = {
  0xd6, 0x03, 0x52, 0xe1 // ldrsb al r0 r2 minus 54 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_30_Offset[] = {
  0xde, 0x01, 0xd2, 0xe1 // ldrsb al r0 r2 plus 30 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_221_Offset[] = {
  0xdd, 0x0d, 0x50, 0xe1 // ldrsb al r0 r0 minus 221 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_plus_34_Offset[] = {
  0xd2, 0x02, 0xdc, 0xe1 // ldrsb al r0 r12 plus 34 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_145_Offset[] = {
  0xd1, 0x09, 0xd4, 0xe1 // ldrsb al r0 r4 plus 145 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_85_Offset[] = {
  0xd5, 0x05, 0xd0, 0xe1 // ldrsb al r0 r0 plus 85 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_plus_64_Offset[] = {
  0xd0, 0x04, 0xd6, 0xe1 // ldrsb al r0 r6 plus 64 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_72_Offset[] = {
  0xd8, 0x04, 0xd9, 0xe1 // ldrsb al r0 r9 plus 72 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_minus_97_Offset[] = {
  0xd1, 0x06, 0x5a, 0xe1 // ldrsb al r0 r10 minus 97 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_186_Offset[] = {
  0xda, 0x0b, 0xd2, 0xe1 // ldrsb al r0 r2 plus 186 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_10_Offset[] = {
  0xda, 0x00, 0xd9, 0xe1 // ldrsb al r0 r9 plus 10 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_minus_236_Offset[] = {
  0xdc, 0x0e, 0x56, 0xe1 // ldrsb al r0 r6 minus 236 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_plus_73_Offset[] = {
  0xd9, 0x04, 0xdd, 0xe1 // ldrsb al r0 r13 plus 73 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_plus_112_Offset[] = {
  0xd0, 0x07, 0xdd, 0xe1 // ldrsb al r0 r13 plus 112 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_101_Offset[] = {
  0xd5, 0x06, 0x50, 0xe1 // ldrsb al r0 r0 minus 101 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_32_Offset[] = {
  0xd0, 0x02, 0xd9, 0xe1 // ldrsb al r0 r9 plus 32 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_57_Offset[] = {
  0xd9, 0x03, 0xd9, 0xe1 // ldrsb al r0 r9 plus 57 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_41_Offset[] = {
  0xd9, 0x02, 0x55, 0xe1 // ldrsb al r0 r5 minus 41 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_plus_199_Offset[] = {
  0xd7, 0x0c, 0xd8, 0xe1 // ldrsb al r0 r8 plus 199 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_208_Offset[] = {
  0xd0, 0x0d, 0xd7, 0xe1 // ldrsb al r0 r7 plus 208 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_63_Offset[] = {
  0xdf, 0x03, 0x52, 0xe1 // ldrsb al r0 r2 minus 63 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_minus_69_Offset[] = {
  0xd5, 0x04, 0x57, 0xe1 // ldrsb al r0 r7 minus 69 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_plus_19_Offset[] = {
  0xd3, 0x01, 0xd8, 0xe1 // ldrsb al r0 r8 plus 19 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_plus_128_Offset[] = {
  0xd0, 0x08, 0xd6, 0xe1 // ldrsb al r0 r6 plus 128 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_185_Offset[] = {
  0xd9, 0x0b, 0xd1, 0xe1 // ldrsb al r0 r1 plus 185 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_198_Offset[] = {
  0xd6, 0x0c, 0x5b, 0xe1 // ldrsb al r0 r11 minus 198 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_172_Offset[] = {
  0xdc, 0x0a, 0x53, 0xe1 // ldrsb al r0 r3 minus 172 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_146_Offset[] = {
  0xd2, 0x09, 0xde, 0xe1 // ldrsb al r0 r14 plus 146 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_226_Offset[] = {
  0xd2, 0x0e, 0xd4, 0xe1 // ldrsb al r0 r4 plus 226 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_73_Offset[] = {
  0xd9, 0x04, 0xd9, 0xe1 // ldrsb al r0 r9 plus 73 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_177_Offset[] = {
  0xd1, 0x0b, 0x5d, 0xe1 // ldrsb al r0 r13 minus 177 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_179_Offset[] = {
  0xd3, 0x0b, 0x5d, 0xe1 // ldrsb al r0 r13 minus 179 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_minus_70_Offset[] = {
  0xd6, 0x04, 0x57, 0xe1 // ldrsb al r0 r7 minus 70 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_132_Offset[] = {
  0xd4, 0x08, 0xd0, 0xe1 // ldrsb al r0 r0 plus 132 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_45_Offset[] = {
  0xdd, 0x02, 0xd3, 0xe1 // ldrsb al r0 r3 plus 45 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_150_Offset[] = {
  0xd6, 0x09, 0xd1, 0xe1 // ldrsb al r0 r1 plus 150 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_203_Offset[] = {
  0xdb, 0x0c, 0xd5, 0xe1 // ldrsb al r0 r5 plus 203 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_minus_107_Offset[] = {
  0xdb, 0x06, 0x57, 0xe1 // ldrsb al r0 r7 minus 107 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_182_Offset[] = {
  0xd6, 0x0b, 0xd3, 0xe1 // ldrsb al r0 r3 plus 182 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_minus_112_Offset[] = {
  0xd0, 0x07, 0x5e, 0xe1 // ldrsb al r0 r14 minus 112 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_49_Offset[] = {
  0xd1, 0x03, 0x52, 0xe1 // ldrsb al r0 r2 minus 49 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_50_Offset[] = {
  0xd2, 0x03, 0xd9, 0xe1 // ldrsb al r0 r9 plus 50 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_minus_153_Offset[] = {
  0xd9, 0x09, 0x5e, 0xe1 // ldrsb al r0 r14 minus 153 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_238_Offset[] = {
  0xde, 0x0e, 0xd5, 0xe1 // ldrsb al r0 r5 plus 238 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_minus_131_Offset[] = {
  0xd3, 0x08, 0x5a, 0xe1 // ldrsb al r0 r10 minus 131 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_95_Offset[] = {
  0xdf, 0x05, 0xd0, 0xe1 // ldrsb al r0 r0 plus 95 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_225_Offset[] = {
  0xd1, 0x0e, 0x55, 0xe1 // ldrsb al r0 r5 minus 225 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_minus_180_Offset[] = {
  0xd4, 0x0b, 0x58, 0xe1 // ldrsb al r0 r8 minus 180 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_plus_173_Offset[] = {
  0xdd, 0x0a, 0xd8, 0xe1 // ldrsb al r0 r8 plus 173 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_161_Offset[] = {
  0xd1, 0x0a, 0x5b, 0xe1 // ldrsb al r0 r11 minus 161 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_plus_65_Offset[] = {
  0xd1, 0x04, 0xdb, 0xe1 // ldrsb al r0 r11 plus 65 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_plus_52_Offset[] = {
  0xd4, 0x03, 0xd8, 0xe1 // ldrsb al r0 r8 plus 52 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_221_Offset[] = {
  0xdd, 0x0d, 0xde, 0xe1 // ldrsb al r0 r14 plus 221 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_176_Offset[] = {
  0xd0, 0x0b, 0x53, 0xe1 // ldrsb al r0 r3 minus 176 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_1_Offset[] = {
  0xd1, 0x00, 0x55, 0xe1 // ldrsb al r0 r5 minus 1 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_minus_139_Offset[] = {
  0xdb, 0x08, 0x58, 0xe1 // ldrsb al r0 r8 minus 139 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_154_Offset[] = {
  0xda, 0x09, 0xd0, 0xe1 // ldrsb al r0 r0 plus 154 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_minus_54_Offset[] = {
  0xd6, 0x03, 0x55, 0xe1 // ldrsb al r0 r5 minus 54 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_29_Offset[] = {
  0xdd, 0x01, 0xd7, 0xe1 // ldrsb al r0 r7 plus 29 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_202_Offset[] = {
  0xda, 0x0c, 0x53, 0xe1 // ldrsb al r0 r3 minus 202 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_minus_136_Offset[] = {
  0xd8, 0x08, 0x5c, 0xe1 // ldrsb al r0 r12 minus 136 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_130_Offset[] = {
  0xd2, 0x08, 0x50, 0xe1 // ldrsb al r0 r0 minus 130 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_30_Offset[] = {
  0xde, 0x01, 0xd3, 0xe1 // ldrsb al r0 r3 plus 30 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_minus_136_Offset[] = {
  0xd8, 0x08, 0x51, 0xe1 // ldrsb al r0 r1 minus 136 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_plus_176_Offset[] = {
  0xd0, 0x0b, 0xd4, 0xe1 // ldrsb al r0 r4 plus 176 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_141_Offset[] = {
  0xdd, 0x08, 0xd2, 0xe1 // ldrsb al r0 r2 plus 141 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_196_Offset[] = {
  0xd4, 0x0c, 0x54, 0xe1 // ldrsb al r0 r4 minus 196 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_minus_55_Offset[] = {
  0xd7, 0x03, 0x59, 0xe1 // ldrsb al r0 r9 minus 55 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_plus_99_Offset[] = {
  0xd3, 0x06, 0xdb, 0xe1 // ldrsb al r0 r11 plus 99 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_plus_169_Offset[] = {
  0xd9, 0x0a, 0xdc, 0xe1 // ldrsb al r0 r12 plus 169 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_91_Offset[] = {
  0xdb, 0x05, 0xd7, 0xe1 // ldrsb al r0 r7 plus 91 Offset
};
const byte kInstruction_ldrsb_al_r0_r10_plus_93_Offset[] = {
  0xdd, 0x05, 0xda, 0xe1 // ldrsb al r0 r10 plus 93 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_77_Offset[] = {
  0xdd, 0x04, 0x54, 0xe1 // ldrsb al r0 r4 minus 77 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_6_Offset[] = {
  0xd6, 0x00, 0xd2, 0xe1 // ldrsb al r0 r2 plus 6 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_31_Offset[] = {
  0xdf, 0x01, 0x5d, 0xe1 // ldrsb al r0 r13 minus 31 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_129_Offset[] = {
  0xd1, 0x08, 0xde, 0xe1 // ldrsb al r0 r14 plus 129 Offset
};
const byte kInstruction_ldrsb_al_r0_r13_minus_198_Offset[] = {
  0xd6, 0x0c, 0x5d, 0xe1 // ldrsb al r0 r13 minus 198 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_33_Offset[] = {
  0xd1, 0x02, 0xd5, 0xe1 // ldrsb al r0 r5 plus 33 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_16_Offset[] = {
  0xd0, 0x01, 0x50, 0xe1 // ldrsb al r0 r0 minus 16 Offset
};
const byte kInstruction_ldrsb_al_r0_r12_minus_14_Offset[] = {
  0xde, 0x00, 0x5c, 0xe1 // ldrsb al r0 r12 minus 14 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_146_Offset[] = {
  0xd2, 0x09, 0xd2, 0xe1 // ldrsb al r0 r2 plus 146 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_174_Offset[] = {
  0xde, 0x0a, 0xd1, 0xe1 // ldrsb al r0 r1 plus 174 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_plus_21_Offset[] = {
  0xd5, 0x01, 0xd2, 0xe1 // ldrsb al r0 r2 plus 21 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_202_Offset[] = {
  0xda, 0x0c, 0xd7, 0xe1 // ldrsb al r0 r7 plus 202 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_36_Offset[] = {
  0xd4, 0x02, 0xd5, 0xe1 // ldrsb al r0 r5 plus 36 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_179_Offset[] = {
  0xd3, 0x0b, 0xd7, 0xe1 // ldrsb al r0 r7 plus 179 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_84_Offset[] = {
  0xd4, 0x05, 0x54, 0xe1 // ldrsb al r0 r4 minus 84 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_plus_73_Offset[] = {
  0xd9, 0x04, 0xd3, 0xe1 // ldrsb al r0 r3 plus 73 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_122_Offset[] = {
  0xda, 0x07, 0x50, 0xe1 // ldrsb al r0 r0 minus 122 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_8_Offset[] = {
  0xd8, 0x00, 0xde, 0xe1 // ldrsb al r0 r14 plus 8 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_plus_94_Offset[] = {
  0xde, 0x05, 0xd7, 0xe1 // ldrsb al r0 r7 plus 94 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_plus_217_Offset[] = {
  0xd9, 0x0d, 0xd8, 0xe1 // ldrsb al r0 r8 plus 217 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_97_Offset[] = {
  0xd1, 0x06, 0x50, 0xe1 // ldrsb al r0 r0 minus 97 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_202_Offset[] = {
  0xda, 0x0c, 0x54, 0xe1 // ldrsb al r0 r4 minus 202 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_minus_28_Offset[] = {
  0xdc, 0x01, 0x5e, 0xe1 // ldrsb al r0 r14 minus 28 Offset
};
const byte kInstruction_ldrsb_al_r0_r14_plus_176_Offset[] = {
  0xd0, 0x0b, 0xde, 0xe1 // ldrsb al r0 r14 plus 176 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_148_Offset[] = {
  0xd4, 0x09, 0x5b, 0xe1 // ldrsb al r0 r11 minus 148 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_204_Offset[] = {
  0xdc, 0x0c, 0x53, 0xe1 // ldrsb al r0 r3 minus 204 Offset
};
const byte kInstruction_ldrsb_al_r0_r8_minus_131_Offset[] = {
  0xd3, 0x08, 0x58, 0xe1 // ldrsb al r0 r8 minus 131 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_plus_125_Offset[] = {
  0xdd, 0x07, 0xd0, 0xe1 // ldrsb al r0 r0 plus 125 Offset
};
const byte kInstruction_ldrsb_al_r0_r4_minus_255_Offset[] = {
  0xdf, 0x0f, 0x54, 0xe1 // ldrsb al r0 r4 minus 255 Offset
};
const byte kInstruction_ldrsb_al_r0_r11_minus_247_Offset[] = {
  0xd7, 0x0f, 0x5b, 0xe1 // ldrsb al r0 r11 minus 247 Offset
};
const byte kInstruction_ldrsb_al_r0_r0_minus_254_Offset[] = {
  0xde, 0x0f, 0x50, 0xe1 // ldrsb al r0 r0 minus 254 Offset
};
const byte kInstruction_ldrsb_al_r0_r3_minus_93_Offset[] = {
  0xdd, 0x05, 0x53, 0xe1 // ldrsb al r0 r3 minus 93 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_137_Offset[] = {
  0xd9, 0x08, 0x52, 0xe1 // ldrsb al r0 r2 minus 137 Offset
};
const byte kInstruction_ldrsb_al_r0_r6_plus_70_Offset[] = {
  0xd6, 0x04, 0xd6, 0xe1 // ldrsb al r0 r6 plus 70 Offset
};
const byte kInstruction_ldrsb_al_r0_r9_plus_155_Offset[] = {
  0xdb, 0x09, 0xd9, 0xe1 // ldrsb al r0 r9 plus 155 Offset
};
const byte kInstruction_ldrsb_al_r0_r7_minus_112_Offset[] = {
  0xd0, 0x07, 0x57, 0xe1 // ldrsb al r0 r7 minus 112 Offset
};
const byte kInstruction_ldrsb_al_r0_r5_plus_135_Offset[] = {
  0xd7, 0x08, 0xd5, 0xe1 // ldrsb al r0 r5 plus 135 Offset
};
const byte kInstruction_ldrsb_al_r0_r1_plus_37_Offset[] = {
  0xd5, 0x02, 0xd1, 0xe1 // ldrsb al r0 r1 plus 37 Offset
};
const byte kInstruction_ldrsb_al_r0_r2_minus_180_PostIndex[] = {
  0xd4, 0x0b, 0x52, 0xe0 // ldrsb al r0 r2 minus 180 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r10_plus_36_PostIndex[] = {
  0xd4, 0x72, 0xda, 0xe0 // ldrsb al r7 r10 plus 36 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r3_minus_99_PreIndex[] = {
  0xd3, 0x56, 0x73, 0xe1 // ldrsb al r5 r3 minus 99 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r8_plus_182_PostIndex[] = {
  0xd6, 0x0b, 0xd8, 0xe0 // ldrsb al r0 r8 plus 182 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r12_plus_161_PreIndex[] = {
  0xd1, 0xda, 0xfc, 0xe1 // ldrsb al r13 r12 plus 161 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r13_minus_132_PreIndex[] = {
  0xd4, 0x48, 0x7d, 0xe1 // ldrsb al r4 r13 minus 132 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r3_minus_116_PostIndex[] = {
  0xd4, 0xb7, 0x53, 0xe0 // ldrsb al r11 r3 minus 116 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r14_minus_116_PreIndex[] = {
  0xd4, 0xb7, 0x7e, 0xe1 // ldrsb al r11 r14 minus 116 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r1_plus_13_PostIndex[] = {
  0xdd, 0x70, 0xd1, 0xe0 // ldrsb al r7 r1 plus 13 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r4_minus_198_PreIndex[] = {
  0xd6, 0x8c, 0x74, 0xe1 // ldrsb al r8 r4 minus 198 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r4_plus_135_PostIndex[] = {
  0xd7, 0x08, 0xd4, 0xe0 // ldrsb al r0 r4 plus 135 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r3_minus_107_PreIndex[] = {
  0xdb, 0xb6, 0x73, 0xe1 // ldrsb al r11 r3 minus 107 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r6_plus_211_PostIndex[] = {
  0xd3, 0xdd, 0xd6, 0xe0 // ldrsb al r13 r6 plus 211 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r8_plus_32_PostIndex[] = {
  0xd0, 0xb2, 0xd8, 0xe0 // ldrsb al r11 r8 plus 32 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r6_plus_83_PreIndex[] = {
  0xd3, 0x75, 0xf6, 0xe1 // ldrsb al r7 r6 plus 83 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r13_minus_79_PostIndex[] = {
  0xdf, 0x04, 0x5d, 0xe0 // ldrsb al r0 r13 minus 79 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r1_minus_124_PreIndex[] = {
  0xdc, 0x27, 0x71, 0xe1 // ldrsb al r2 r1 minus 124 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r10_plus_91_PostIndex[] = {
  0xdb, 0x55, 0xda, 0xe0 // ldrsb al r5 r10 plus 91 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r4_minus_138_PreIndex[] = {
  0xda, 0x58, 0x74, 0xe1 // ldrsb al r5 r4 minus 138 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r12_plus_78_PostIndex[] = {
  0xde, 0xa4, 0xdc, 0xe0 // ldrsb al r10 r12 plus 78 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r2_plus_57_PreIndex[] = {
  0xd9, 0x03, 0xf2, 0xe1 // ldrsb al r0 r2 plus 57 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r0_plus_58_PostIndex[] = {
  0xda, 0x23, 0xd0, 0xe0 // ldrsb al r2 r0 plus 58 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r5_plus_249_PreIndex[] = {
  0xd9, 0xaf, 0xf5, 0xe1 // ldrsb al r10 r5 plus 249 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r8_minus_122_PostIndex[] = {
  0xda, 0xb7, 0x58, 0xe0 // ldrsb al r11 r8 minus 122 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r4_minus_163_PreIndex[] = {
  0xd3, 0x5a, 0x74, 0xe1 // ldrsb al r5 r4 minus 163 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r14_plus_130_PreIndex[] = {
  0xd2, 0x68, 0xfe, 0xe1 // ldrsb al r6 r14 plus 130 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r9_plus_175_PreIndex[] = {
  0xdf, 0x0a, 0xf9, 0xe1 // ldrsb al r0 r9 plus 175 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r9_minus_79_PostIndex[] = {
  0xdf, 0x64, 0x59, 0xe0 // ldrsb al r6 r9 minus 79 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r2_plus_14_PreIndex[] = {
  0xde, 0x00, 0xf2, 0xe1 // ldrsb al r0 r2 plus 14 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r4_minus_129_PreIndex[] = {
  0xd1, 0x98, 0x74, 0xe1 // ldrsb al r9 r4 minus 129 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r0_minus_179_PreIndex[] = {
  0xd3, 0xbb, 0x70, 0xe1 // ldrsb al r11 r0 minus 179 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r11_minus_100_PreIndex[] = {
  0xd4, 0x26, 0x7b, 0xe1 // ldrsb al r2 r11 minus 100 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r11_minus_246_PostIndex[] = {
  0xd6, 0x3f, 0x5b, 0xe0 // ldrsb al r3 r11 minus 246 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r4_minus_38_PostIndex[] = {
  0xd6, 0x12, 0x54, 0xe0 // ldrsb al r1 r4 minus 38 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r14_plus_216_PreIndex[] = {
  0xd8, 0xcd, 0xfe, 0xe1 // ldrsb al r12 r14 plus 216 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r5_minus_37_PreIndex[] = {
  0xd5, 0xd2, 0x75, 0xe1 // ldrsb al r13 r5 minus 37 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r10_minus_90_PostIndex[] = {
  0xda, 0x95, 0x5a, 0xe0 // ldrsb al r9 r10 minus 90 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r14_plus_115_PostIndex[] = {
  0xd3, 0x17, 0xde, 0xe0 // ldrsb al r1 r14 plus 115 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r13_plus_194_PostIndex[] = {
  0xd2, 0x0c, 0xdd, 0xe0 // ldrsb al r0 r13 plus 194 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r14_minus_162_PreIndex[] = {
  0xd2, 0xda, 0x7e, 0xe1 // ldrsb al r13 r14 minus 162 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r3_minus_251_PostIndex[] = {
  0xdb, 0x2f, 0x53, 0xe0 // ldrsb al r2 r3 minus 251 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r3_plus_190_PostIndex[] = {
  0xde, 0x2b, 0xd3, 0xe0 // ldrsb al r2 r3 plus 190 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r13_minus_47_PostIndex[] = {
  0xdf, 0x02, 0x5d, 0xe0 // ldrsb al r0 r13 minus 47 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r4_minus_59_PostIndex[] = {
  0xdb, 0xe3, 0x54, 0xe0 // ldrsb al r14 r4 minus 59 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r0_plus_62_PreIndex[] = {
  0xde, 0xa3, 0xf0, 0xe1 // ldrsb al r10 r0 plus 62 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r14_minus_239_PostIndex[] = {
  0xdf, 0x1e, 0x5e, 0xe0 // ldrsb al r1 r14 minus 239 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r3_minus_29_PostIndex[] = {
  0xdd, 0x41, 0x53, 0xe0 // ldrsb al r4 r3 minus 29 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r14_plus_174_PreIndex[] = {
  0xde, 0x4a, 0xfe, 0xe1 // ldrsb al r4 r14 plus 174 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r5_minus_167_PostIndex[] = {
  0xd7, 0x7a, 0x55, 0xe0 // ldrsb al r7 r5 minus 167 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r11_minus_46_PreIndex[] = {
  0xde, 0x52, 0x7b, 0xe1 // ldrsb al r5 r11 minus 46 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r13_plus_13_PostIndex[] = {
  0xdd, 0x30, 0xdd, 0xe0 // ldrsb al r3 r13 plus 13 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r7_plus_10_PreIndex[] = {
  0xda, 0x30, 0xf7, 0xe1 // ldrsb al r3 r7 plus 10 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r5_minus_95_PostIndex[] = {
  0xdf, 0x45, 0x55, 0xe0 // ldrsb al r4 r5 minus 95 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r8_minus_17_PostIndex[] = {
  0xd1, 0xb1, 0x58, 0xe0 // ldrsb al r11 r8 minus 17 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r10_plus_72_PostIndex[] = {
  0xd8, 0x24, 0xda, 0xe0 // ldrsb al r2 r10 plus 72 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r12_minus_6_PostIndex[] = {
  0xd6, 0x00, 0x5c, 0xe0 // ldrsb al r0 r12 minus 6 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r4_plus_232_PostIndex[] = {
  0xd8, 0xee, 0xd4, 0xe0 // ldrsb al r14 r4 plus 232 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r9_plus_62_PostIndex[] = {
  0xde, 0x63, 0xd9, 0xe0 // ldrsb al r6 r9 plus 62 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r14_minus_251_PreIndex[] = {
  0xdb, 0x6f, 0x7e, 0xe1 // ldrsb al r6 r14 minus 251 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r3_plus_213_PostIndex[] = {
  0xd5, 0xad, 0xd3, 0xe0 // ldrsb al r10 r3 plus 213 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r5_plus_95_PreIndex[] = {
  0xdf, 0x45, 0xf5, 0xe1 // ldrsb al r4 r5 plus 95 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r12_plus_90_PreIndex[] = {
  0xda, 0xd5, 0xfc, 0xe1 // ldrsb al r13 r12 plus 90 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r8_minus_117_PostIndex[] = {
  0xd5, 0x17, 0x58, 0xe0 // ldrsb al r1 r8 minus 117 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r3_minus_9_PreIndex[] = {
  0xd9, 0xd0, 0x73, 0xe1 // ldrsb al r13 r3 minus 9 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r4_plus_174_PostIndex[] = {
  0xde, 0x6a, 0xd4, 0xe0 // ldrsb al r6 r4 plus 174 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r10_plus_85_PostIndex[] = {
  0xd5, 0xe5, 0xda, 0xe0 // ldrsb al r14 r10 plus 85 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r3_plus_77_PostIndex[] = {
  0xdd, 0xa4, 0xd3, 0xe0 // ldrsb al r10 r3 plus 77 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r12_minus_124_PostIndex[] = {
  0xdc, 0x87, 0x5c, 0xe0 // ldrsb al r8 r12 minus 124 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r2_minus_66_PostIndex[] = {
  0xd2, 0x04, 0x52, 0xe0 // ldrsb al r0 r2 minus 66 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r0_minus_121_PreIndex[] = {
  0xd9, 0x67, 0x70, 0xe1 // ldrsb al r6 r0 minus 121 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r4_minus_10_PostIndex[] = {
  0xda, 0x10, 0x54, 0xe0 // ldrsb al r1 r4 minus 10 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r5_plus_35_PreIndex[] = {
  0xd3, 0x02, 0xf5, 0xe1 // ldrsb al r0 r5 plus 35 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r2_plus_76_PostIndex[] = {
  0xdc, 0xb4, 0xd2, 0xe0 // ldrsb al r11 r2 plus 76 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r13_plus_162_PreIndex[] = {
  0xd2, 0x4a, 0xfd, 0xe1 // ldrsb al r4 r13 plus 162 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r4_plus_219_PreIndex[] = {
  0xdb, 0x9d, 0xf4, 0xe1 // ldrsb al r9 r4 plus 219 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r3_plus_92_PreIndex[] = {
  0xdc, 0x25, 0xf3, 0xe1 // ldrsb al r2 r3 plus 92 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r0_plus_173_PostIndex[] = {
  0xdd, 0x4a, 0xd0, 0xe0 // ldrsb al r4 r0 plus 173 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r4_minus_92_PreIndex[] = {
  0xdc, 0x05, 0x74, 0xe1 // ldrsb al r0 r4 minus 92 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r4_plus_198_PreIndex[] = {
  0xd6, 0x1c, 0xf4, 0xe1 // ldrsb al r1 r4 plus 198 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r11_plus_164_PreIndex[] = {
  0xd4, 0x4a, 0xfb, 0xe1 // ldrsb al r4 r11 plus 164 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r3_plus_29_PreIndex[] = {
  0xdd, 0xa1, 0xf3, 0xe1 // ldrsb al r10 r3 plus 29 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r4_plus_129_PreIndex[] = {
  0xd1, 0x08, 0xf4, 0xe1 // ldrsb al r0 r4 plus 129 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r8_plus_120_PreIndex[] = {
  0xd8, 0xe7, 0xf8, 0xe1 // ldrsb al r14 r8 plus 120 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r10_plus_187_PostIndex[] = {
  0xdb, 0xbb, 0xda, 0xe0 // ldrsb al r11 r10 plus 187 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r0_plus_69_PostIndex[] = {
  0xd5, 0x24, 0xd0, 0xe0 // ldrsb al r2 r0 plus 69 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r7_plus_130_PreIndex[] = {
  0xd2, 0x98, 0xf7, 0xe1 // ldrsb al r9 r7 plus 130 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r5_minus_59_PreIndex[] = {
  0xdb, 0xa3, 0x75, 0xe1 // ldrsb al r10 r5 minus 59 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r2_plus_196_PreIndex[] = {
  0xd4, 0xdc, 0xf2, 0xe1 // ldrsb al r13 r2 plus 196 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r6_plus_27_PreIndex[] = {
  0xdb, 0xc1, 0xf6, 0xe1 // ldrsb al r12 r6 plus 27 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r0_plus_30_PostIndex[] = {
  0xde, 0x91, 0xd0, 0xe0 // ldrsb al r9 r0 plus 30 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r11_plus_208_PostIndex[] = {
  0xd0, 0x8d, 0xdb, 0xe0 // ldrsb al r8 r11 plus 208 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r10_plus_150_PostIndex[] = {
  0xd6, 0x69, 0xda, 0xe0 // ldrsb al r6 r10 plus 150 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r9_plus_115_PostIndex[] = {
  0xd3, 0x37, 0xd9, 0xe0 // ldrsb al r3 r9 plus 115 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r14_minus_65_PreIndex[] = {
  0xd1, 0x24, 0x7e, 0xe1 // ldrsb al r2 r14 minus 65 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r9_plus_150_PreIndex[] = {
  0xd6, 0xc9, 0xf9, 0xe1 // ldrsb al r12 r9 plus 150 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r11_plus_153_PostIndex[] = {
  0xd9, 0x29, 0xdb, 0xe0 // ldrsb al r2 r11 plus 153 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r11_minus_80_PostIndex[] = {
  0xd0, 0x45, 0x5b, 0xe0 // ldrsb al r4 r11 minus 80 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r11_minus_164_PostIndex[] = {
  0xd4, 0x8a, 0x5b, 0xe0 // ldrsb al r8 r11 minus 164 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r9_plus_140_PreIndex[] = {
  0xdc, 0x88, 0xf9, 0xe1 // ldrsb al r8 r9 plus 140 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r1_minus_237_PreIndex[] = {
  0xdd, 0x4e, 0x71, 0xe1 // ldrsb al r4 r1 minus 237 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r4_plus_16_PostIndex[] = {
  0xd0, 0x91, 0xd4, 0xe0 // ldrsb al r9 r4 plus 16 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r6_plus_248_PreIndex[] = {
  0xd8, 0xdf, 0xf6, 0xe1 // ldrsb al r13 r6 plus 248 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r12_plus_196_PostIndex[] = {
  0xd4, 0x9c, 0xdc, 0xe0 // ldrsb al r9 r12 plus 196 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r1_plus_68_PostIndex[] = {
  0xd4, 0x24, 0xd1, 0xe0 // ldrsb al r2 r1 plus 68 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r2_minus_106_PreIndex[] = {
  0xda, 0x16, 0x72, 0xe1 // ldrsb al r1 r2 minus 106 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r9_minus_21_PreIndex[] = {
  0xd5, 0x31, 0x79, 0xe1 // ldrsb al r3 r9 minus 21 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r3_plus_39_PreIndex[] = {
  0xd7, 0xd2, 0xf3, 0xe1 // ldrsb al r13 r3 plus 39 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r11_plus_75_PostIndex[] = {
  0xdb, 0x24, 0xdb, 0xe0 // ldrsb al r2 r11 plus 75 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r3_minus_136_PostIndex[] = {
  0xd8, 0x58, 0x53, 0xe0 // ldrsb al r5 r3 minus 136 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r13_minus_229_PreIndex[] = {
  0xd5, 0xce, 0x7d, 0xe1 // ldrsb al r12 r13 minus 229 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r5_plus_130_PostIndex[] = {
  0xd2, 0x98, 0xd5, 0xe0 // ldrsb al r9 r5 plus 130 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r5_plus_206_PostIndex[] = {
  0xde, 0x2c, 0xd5, 0xe0 // ldrsb al r2 r5 plus 206 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r6_minus_6_PreIndex[] = {
  0xd6, 0x40, 0x76, 0xe1 // ldrsb al r4 r6 minus 6 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r13_plus_113_PreIndex[] = {
  0xd1, 0xe7, 0xfd, 0xe1 // ldrsb al r14 r13 plus 113 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r5_plus_128_PostIndex[] = {
  0xd0, 0x18, 0xd5, 0xe0 // ldrsb al r1 r5 plus 128 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r4_plus_171_PostIndex[] = {
  0xdb, 0x2a, 0xd4, 0xe0 // ldrsb al r2 r4 plus 171 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r0_minus_125_PostIndex[] = {
  0xdd, 0x67, 0x50, 0xe0 // ldrsb al r6 r0 minus 125 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r12_plus_224_PostIndex[] = {
  0xd0, 0xee, 0xdc, 0xe0 // ldrsb al r14 r12 plus 224 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r6_minus_185_PreIndex[] = {
  0xd9, 0xcb, 0x76, 0xe1 // ldrsb al r12 r6 minus 185 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r0_plus_143_PostIndex[] = {
  0xdf, 0x68, 0xd0, 0xe0 // ldrsb al r6 r0 plus 143 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r13_plus_219_PostIndex[] = {
  0xdb, 0x4d, 0xdd, 0xe0 // ldrsb al r4 r13 plus 219 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r0_plus_187_PostIndex[] = {
  0xdb, 0xdb, 0xd0, 0xe0 // ldrsb al r13 r0 plus 187 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r0_plus_103_PreIndex[] = {
  0xd7, 0xe6, 0xf0, 0xe1 // ldrsb al r14 r0 plus 103 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r2_minus_73_PostIndex[] = {
  0xd9, 0x54, 0x52, 0xe0 // ldrsb al r5 r2 minus 73 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r11_plus_109_PostIndex[] = {
  0xdd, 0x36, 0xdb, 0xe0 // ldrsb al r3 r11 plus 109 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r5_plus_22_PreIndex[] = {
  0xd6, 0x21, 0xf5, 0xe1 // ldrsb al r2 r5 plus 22 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r5_minus_123_PostIndex[] = {
  0xdb, 0xd7, 0x55, 0xe0 // ldrsb al r13 r5 minus 123 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r5_minus_133_PreIndex[] = {
  0xd5, 0xe8, 0x75, 0xe1 // ldrsb al r14 r5 minus 133 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r11_minus_226_PostIndex[] = {
  0xd2, 0xae, 0x5b, 0xe0 // ldrsb al r10 r11 minus 226 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r6_plus_175_PostIndex[] = {
  0xdf, 0x3a, 0xd6, 0xe0 // ldrsb al r3 r6 plus 175 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r11_minus_6_PreIndex[] = {
  0xd6, 0x00, 0x7b, 0xe1 // ldrsb al r0 r11 minus 6 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r1_plus_170_PostIndex[] = {
  0xda, 0x7a, 0xd1, 0xe0 // ldrsb al r7 r1 plus 170 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r7_plus_107_PostIndex[] = {
  0xdb, 0xc6, 0xd7, 0xe0 // ldrsb al r12 r7 plus 107 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r11_minus_109_PostIndex[] = {
  0xdd, 0x86, 0x5b, 0xe0 // ldrsb al r8 r11 minus 109 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r0_minus_93_PreIndex[] = {
  0xdd, 0x85, 0x70, 0xe1 // ldrsb al r8 r0 minus 93 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r3_minus_152_PostIndex[] = {
  0xd8, 0x99, 0x53, 0xe0 // ldrsb al r9 r3 minus 152 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r12_minus_233_PostIndex[] = {
  0xd9, 0x9e, 0x5c, 0xe0 // ldrsb al r9 r12 minus 233 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r2_minus_122_PostIndex[] = {
  0xda, 0x57, 0x52, 0xe0 // ldrsb al r5 r2 minus 122 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r9_plus_248_PostIndex[] = {
  0xd8, 0x2f, 0xd9, 0xe0 // ldrsb al r2 r9 plus 248 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r14_minus_137_PreIndex[] = {
  0xd9, 0x28, 0x7e, 0xe1 // ldrsb al r2 r14 minus 137 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r12_plus_19_PreIndex[] = {
  0xd3, 0xa1, 0xfc, 0xe1 // ldrsb al r10 r12 plus 19 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r10_plus_116_PostIndex[] = {
  0xd4, 0x77, 0xda, 0xe0 // ldrsb al r7 r10 plus 116 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r8_minus_46_PreIndex[] = {
  0xde, 0xb2, 0x78, 0xe1 // ldrsb al r11 r8 minus 46 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r9_minus_16_PreIndex[] = {
  0xd0, 0x41, 0x79, 0xe1 // ldrsb al r4 r9 minus 16 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r9_minus_74_PostIndex[] = {
  0xda, 0x84, 0x59, 0xe0 // ldrsb al r8 r9 minus 74 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r9_minus_7_PostIndex[] = {
  0xd7, 0xd0, 0x59, 0xe0 // ldrsb al r13 r9 minus 7 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r6_plus_100_PostIndex[] = {
  0xd4, 0x76, 0xd6, 0xe0 // ldrsb al r7 r6 plus 100 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r1_minus_217_PostIndex[] = {
  0xd9, 0xdd, 0x51, 0xe0 // ldrsb al r13 r1 minus 217 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r0_plus_219_PreIndex[] = {
  0xdb, 0x5d, 0xf0, 0xe1 // ldrsb al r5 r0 plus 219 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r1_minus_148_PreIndex[] = {
  0xd4, 0x99, 0x71, 0xe1 // ldrsb al r9 r1 minus 148 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r8_plus_211_PreIndex[] = {
  0xd3, 0x0d, 0xf8, 0xe1 // ldrsb al r0 r8 plus 211 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r6_plus_82_PreIndex[] = {
  0xd2, 0x95, 0xf6, 0xe1 // ldrsb al r9 r6 plus 82 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r1_minus_222_PreIndex[] = {
  0xde, 0x0d, 0x71, 0xe1 // ldrsb al r0 r1 minus 222 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r1_plus_225_PostIndex[] = {
  0xd1, 0x3e, 0xd1, 0xe0 // ldrsb al r3 r1 plus 225 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r2_minus_28_PostIndex[] = {
  0xdc, 0x51, 0x52, 0xe0 // ldrsb al r5 r2 minus 28 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r5_minus_24_PostIndex[] = {
  0xd8, 0x71, 0x55, 0xe0 // ldrsb al r7 r5 minus 24 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r8_minus_55_PreIndex[] = {
  0xd7, 0x43, 0x78, 0xe1 // ldrsb al r4 r8 minus 55 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r14_minus_90_PostIndex[] = {
  0xda, 0x65, 0x5e, 0xe0 // ldrsb al r6 r14 minus 90 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r0_minus_158_PreIndex[] = {
  0xde, 0x39, 0x70, 0xe1 // ldrsb al r3 r0 minus 158 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r8_plus_239_PostIndex[] = {
  0xdf, 0xae, 0xd8, 0xe0 // ldrsb al r10 r8 plus 239 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r5_plus_185_PostIndex[] = {
  0xd9, 0x4b, 0xd5, 0xe0 // ldrsb al r4 r5 plus 185 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r3_minus_34_PreIndex[] = {
  0xd2, 0x52, 0x73, 0xe1 // ldrsb al r5 r3 minus 34 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r0_minus_129_PostIndex[] = {
  0xd1, 0xb8, 0x50, 0xe0 // ldrsb al r11 r0 minus 129 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r9_minus_175_PreIndex[] = {
  0xdf, 0x2a, 0x79, 0xe1 // ldrsb al r2 r9 minus 175 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r13_plus_87_PreIndex[] = {
  0xd7, 0x25, 0xfd, 0xe1 // ldrsb al r2 r13 plus 87 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r7_plus_34_PostIndex[] = {
  0xd2, 0x82, 0xd7, 0xe0 // ldrsb al r8 r7 plus 34 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r1_minus_124_PostIndex[] = {
  0xdc, 0x37, 0x51, 0xe0 // ldrsb al r3 r1 minus 124 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r0_minus_163_PostIndex[] = {
  0xd3, 0xca, 0x50, 0xe0 // ldrsb al r12 r0 minus 163 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r11_minus_88_PostIndex[] = {
  0xd8, 0x95, 0x5b, 0xe0 // ldrsb al r9 r11 minus 88 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r13_minus_143_PostIndex[] = {
  0xdf, 0xb8, 0x5d, 0xe0 // ldrsb al r11 r13 minus 143 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r12_plus_247_PostIndex[] = {
  0xd7, 0x6f, 0xdc, 0xe0 // ldrsb al r6 r12 plus 247 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r1_plus_47_PostIndex[] = {
  0xdf, 0x42, 0xd1, 0xe0 // ldrsb al r4 r1 plus 47 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r2_plus_228_PreIndex[] = {
  0xd4, 0x5e, 0xf2, 0xe1 // ldrsb al r5 r2 plus 228 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r13_minus_200_PreIndex[] = {
  0xd8, 0x6c, 0x7d, 0xe1 // ldrsb al r6 r13 minus 200 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r0_plus_188_PreIndex[] = {
  0xdc, 0xab, 0xf0, 0xe1 // ldrsb al r10 r0 plus 188 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r9_plus_19_PostIndex[] = {
  0xd3, 0xc1, 0xd9, 0xe0 // ldrsb al r12 r9 plus 19 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r6_minus_184_PostIndex[] = {
  0xd8, 0x3b, 0x56, 0xe0 // ldrsb al r3 r6 minus 184 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r10_plus_229_PostIndex[] = {
  0xd5, 0xce, 0xda, 0xe0 // ldrsb al r12 r10 plus 229 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r3_minus_179_PreIndex[] = {
  0xd3, 0x5b, 0x73, 0xe1 // ldrsb al r5 r3 minus 179 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r9_plus_120_PostIndex[] = {
  0xd8, 0xc7, 0xd9, 0xe0 // ldrsb al r12 r9 plus 120 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r10_plus_143_PreIndex[] = {
  0xdf, 0x98, 0xfa, 0xe1 // ldrsb al r9 r10 plus 143 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r2_minus_148_PostIndex[] = {
  0xd4, 0x19, 0x52, 0xe0 // ldrsb al r1 r2 minus 148 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r1_plus_210_PreIndex[] = {
  0xd2, 0x7d, 0xf1, 0xe1 // ldrsb al r7 r1 plus 210 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r12_plus_208_PreIndex[] = {
  0xd0, 0x5d, 0xfc, 0xe1 // ldrsb al r5 r12 plus 208 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r8_plus_6_PreIndex[] = {
  0xd6, 0x10, 0xf8, 0xe1 // ldrsb al r1 r8 plus 6 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r6_minus_106_PreIndex[] = {
  0xda, 0x96, 0x76, 0xe1 // ldrsb al r9 r6 minus 106 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r9_minus_59_PostIndex[] = {
  0xdb, 0x13, 0x59, 0xe0 // ldrsb al r1 r9 minus 59 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r11_minus_18_PreIndex[] = {
  0xd2, 0x61, 0x7b, 0xe1 // ldrsb al r6 r11 minus 18 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r7_plus_19_PreIndex[] = {
  0xd3, 0x21, 0xf7, 0xe1 // ldrsb al r2 r7 plus 19 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r5_minus_229_PreIndex[] = {
  0xd5, 0xce, 0x75, 0xe1 // ldrsb al r12 r5 minus 229 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r5_minus_60_PostIndex[] = {
  0xdc, 0x83, 0x55, 0xe0 // ldrsb al r8 r5 minus 60 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r8_minus_125_PreIndex[] = {
  0xdd, 0x97, 0x78, 0xe1 // ldrsb al r9 r8 minus 125 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r13_plus_137_PostIndex[] = {
  0xd9, 0xe8, 0xdd, 0xe0 // ldrsb al r14 r13 plus 137 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r1_plus_1_PostIndex[] = {
  0xd1, 0x90, 0xd1, 0xe0 // ldrsb al r9 r1 plus 1 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r2_plus_230_PostIndex[] = {
  0xd6, 0x6e, 0xd2, 0xe0 // ldrsb al r6 r2 plus 230 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r0_plus_218_PostIndex[] = {
  0xda, 0xbd, 0xd0, 0xe0 // ldrsb al r11 r0 plus 218 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r10_plus_125_PostIndex[] = {
  0xdd, 0x87, 0xda, 0xe0 // ldrsb al r8 r10 plus 125 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r4_plus_138_PostIndex[] = {
  0xda, 0x18, 0xd4, 0xe0 // ldrsb al r1 r4 plus 138 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r9_minus_66_PreIndex[] = {
  0xd2, 0xa4, 0x79, 0xe1 // ldrsb al r10 r9 minus 66 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r11_plus_25_PreIndex[] = {
  0xd9, 0xe1, 0xfb, 0xe1 // ldrsb al r14 r11 plus 25 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r3_minus_76_PostIndex[] = {
  0xdc, 0x94, 0x53, 0xe0 // ldrsb al r9 r3 minus 76 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r14_plus_8_PostIndex[] = {
  0xd8, 0x90, 0xde, 0xe0 // ldrsb al r9 r14 plus 8 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r14_plus_67_PostIndex[] = {
  0xd3, 0x34, 0xde, 0xe0 // ldrsb al r3 r14 plus 67 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r0_minus_39_PreIndex[] = {
  0xd7, 0x32, 0x70, 0xe1 // ldrsb al r3 r0 minus 39 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r1_minus_17_PreIndex[] = {
  0xd1, 0x81, 0x71, 0xe1 // ldrsb al r8 r1 minus 17 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r11_minus_223_PreIndex[] = {
  0xdf, 0xed, 0x7b, 0xe1 // ldrsb al r14 r11 minus 223 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r10_plus_99_PreIndex[] = {
  0xd3, 0x76, 0xfa, 0xe1 // ldrsb al r7 r10 plus 99 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r11_minus_12_PostIndex[] = {
  0xdc, 0xe0, 0x5b, 0xe0 // ldrsb al r14 r11 minus 12 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r10_minus_235_PostIndex[] = {
  0xdb, 0xde, 0x5a, 0xe0 // ldrsb al r13 r10 minus 235 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r13_minus_167_PreIndex[] = {
  0xd7, 0x3a, 0x7d, 0xe1 // ldrsb al r3 r13 minus 167 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r11_plus_222_PostIndex[] = {
  0xde, 0xdd, 0xdb, 0xe0 // ldrsb al r13 r11 plus 222 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r4_minus_20_PreIndex[] = {
  0xd4, 0x21, 0x74, 0xe1 // ldrsb al r2 r4 minus 20 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r3_plus_185_PostIndex[] = {
  0xd9, 0x1b, 0xd3, 0xe0 // ldrsb al r1 r3 plus 185 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r1_plus_115_PostIndex[] = {
  0xd3, 0x07, 0xd1, 0xe0 // ldrsb al r0 r1 plus 115 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r0_plus_169_PreIndex[] = {
  0xd9, 0x2a, 0xf0, 0xe1 // ldrsb al r2 r0 plus 169 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r5_plus_121_PostIndex[] = {
  0xd9, 0xb7, 0xd5, 0xe0 // ldrsb al r11 r5 plus 121 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r12_minus_114_PostIndex[] = {
  0xd2, 0x57, 0x5c, 0xe0 // ldrsb al r5 r12 minus 114 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r13_minus_71_PostIndex[] = {
  0xd7, 0xe4, 0x5d, 0xe0 // ldrsb al r14 r13 minus 71 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r10_plus_127_PreIndex[] = {
  0xdf, 0xc7, 0xfa, 0xe1 // ldrsb al r12 r10 plus 127 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r11_minus_125_PostIndex[] = {
  0xdd, 0x87, 0x5b, 0xe0 // ldrsb al r8 r11 minus 125 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r9_plus_239_PostIndex[] = {
  0xdf, 0xde, 0xd9, 0xe0 // ldrsb al r13 r9 plus 239 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r1_plus_74_PreIndex[] = {
  0xda, 0x34, 0xf1, 0xe1 // ldrsb al r3 r1 plus 74 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r7_minus_229_PostIndex[] = {
  0xd5, 0x8e, 0x57, 0xe0 // ldrsb al r8 r7 minus 229 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r1_plus_240_PostIndex[] = {
  0xd0, 0x8f, 0xd1, 0xe0 // ldrsb al r8 r1 plus 240 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r4_minus_51_PreIndex[] = {
  0xd3, 0x23, 0x74, 0xe1 // ldrsb al r2 r4 minus 51 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r9_minus_103_PreIndex[] = {
  0xd7, 0xd6, 0x79, 0xe1 // ldrsb al r13 r9 minus 103 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r6_minus_138_PostIndex[] = {
  0xda, 0x48, 0x56, 0xe0 // ldrsb al r4 r6 minus 138 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r0_minus_145_PostIndex[] = {
  0xd1, 0xb9, 0x50, 0xe0 // ldrsb al r11 r0 minus 145 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r3_plus_232_PostIndex[] = {
  0xd8, 0x6e, 0xd3, 0xe0 // ldrsb al r6 r3 plus 232 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r2_plus_117_PreIndex[] = {
  0xd5, 0xe7, 0xf2, 0xe1 // ldrsb al r14 r2 plus 117 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r6_plus_224_PreIndex[] = {
  0xd0, 0x5e, 0xf6, 0xe1 // ldrsb al r5 r6 plus 224 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r2_minus_192_PostIndex[] = {
  0xd0, 0x7c, 0x52, 0xe0 // ldrsb al r7 r2 minus 192 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r8_plus_250_PreIndex[] = {
  0xda, 0xef, 0xf8, 0xe1 // ldrsb al r14 r8 plus 250 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r11_minus_34_PreIndex[] = {
  0xd2, 0x82, 0x7b, 0xe1 // ldrsb al r8 r11 minus 34 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r11_minus_153_PreIndex[] = {
  0xd9, 0xc9, 0x7b, 0xe1 // ldrsb al r12 r11 minus 153 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r0_minus_61_PreIndex[] = {
  0xdd, 0x43, 0x70, 0xe1 // ldrsb al r4 r0 minus 61 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r12_plus_158_PostIndex[] = {
  0xde, 0x39, 0xdc, 0xe0 // ldrsb al r3 r12 plus 158 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r12_plus_212_PreIndex[] = {
  0xd4, 0x6d, 0xfc, 0xe1 // ldrsb al r6 r12 plus 212 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r10_plus_189_PostIndex[] = {
  0xdd, 0x6b, 0xda, 0xe0 // ldrsb al r6 r10 plus 189 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r6_plus_234_PostIndex[] = {
  0xda, 0x2e, 0xd6, 0xe0 // ldrsb al r2 r6 plus 234 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r11_minus_134_PostIndex[] = {
  0xd6, 0xa8, 0x5b, 0xe0 // ldrsb al r10 r11 minus 134 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r6_minus_240_PostIndex[] = {
  0xd0, 0xbf, 0x56, 0xe0 // ldrsb al r11 r6 minus 240 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r10_minus_162_PreIndex[] = {
  0xd2, 0x1a, 0x7a, 0xe1 // ldrsb al r1 r10 minus 162 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r3_plus_235_PostIndex[] = {
  0xdb, 0x8e, 0xd3, 0xe0 // ldrsb al r8 r3 plus 235 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r12_plus_192_PreIndex[] = {
  0xd0, 0x5c, 0xfc, 0xe1 // ldrsb al r5 r12 plus 192 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r3_minus_13_PostIndex[] = {
  0xdd, 0xb0, 0x53, 0xe0 // ldrsb al r11 r3 minus 13 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r5_plus_192_PostIndex[] = {
  0xd0, 0x3c, 0xd5, 0xe0 // ldrsb al r3 r5 plus 192 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r5_plus_75_PreIndex[] = {
  0xdb, 0x14, 0xf5, 0xe1 // ldrsb al r1 r5 plus 75 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r7_plus_9_PostIndex[] = {
  0xd9, 0x10, 0xd7, 0xe0 // ldrsb al r1 r7 plus 9 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r14_plus_103_PreIndex[] = {
  0xd7, 0x16, 0xfe, 0xe1 // ldrsb al r1 r14 plus 103 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r5_plus_254_PostIndex[] = {
  0xde, 0x4f, 0xd5, 0xe0 // ldrsb al r4 r5 plus 254 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r3_plus_219_PreIndex[] = {
  0xdb, 0x7d, 0xf3, 0xe1 // ldrsb al r7 r3 plus 219 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r7_minus_233_PreIndex[] = {
  0xd9, 0x6e, 0x77, 0xe1 // ldrsb al r6 r7 minus 233 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r6_plus_93_PostIndex[] = {
  0xdd, 0x75, 0xd6, 0xe0 // ldrsb al r7 r6 plus 93 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r14_plus_15_PreIndex[] = {
  0xdf, 0x50, 0xfe, 0xe1 // ldrsb al r5 r14 plus 15 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r2_plus_51_PreIndex[] = {
  0xd3, 0x43, 0xf2, 0xe1 // ldrsb al r4 r2 plus 51 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r7_plus_233_PostIndex[] = {
  0xd9, 0xce, 0xd7, 0xe0 // ldrsb al r12 r7 plus 233 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r8_plus_219_PostIndex[] = {
  0xdb, 0xbd, 0xd8, 0xe0 // ldrsb al r11 r8 plus 219 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r10_minus_189_PostIndex[] = {
  0xdd, 0x1b, 0x5a, 0xe0 // ldrsb al r1 r10 minus 189 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r13_minus_101_PostIndex[] = {
  0xd5, 0x46, 0x5d, 0xe0 // ldrsb al r4 r13 minus 101 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r12_minus_46_PreIndex[] = {
  0xde, 0x42, 0x7c, 0xe1 // ldrsb al r4 r12 minus 46 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r12_minus_195_PreIndex[] = {
  0xd3, 0xec, 0x7c, 0xe1 // ldrsb al r14 r12 minus 195 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r2_minus_141_PreIndex[] = {
  0xdd, 0x88, 0x72, 0xe1 // ldrsb al r8 r2 minus 141 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r3_plus_191_PostIndex[] = {
  0xdf, 0x5b, 0xd3, 0xe0 // ldrsb al r5 r3 plus 191 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r1_plus_216_PostIndex[] = {
  0xd8, 0x7d, 0xd1, 0xe0 // ldrsb al r7 r1 plus 216 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r13_minus_87_PostIndex[] = {
  0xd7, 0x65, 0x5d, 0xe0 // ldrsb al r6 r13 minus 87 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r8_minus_39_PreIndex[] = {
  0xd7, 0xb2, 0x78, 0xe1 // ldrsb al r11 r8 minus 39 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r6_minus_181_PreIndex[] = {
  0xd5, 0x1b, 0x76, 0xe1 // ldrsb al r1 r6 minus 181 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r4_plus_162_PostIndex[] = {
  0xd2, 0x6a, 0xd4, 0xe0 // ldrsb al r6 r4 plus 162 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r3_minus_81_PreIndex[] = {
  0xd1, 0xe5, 0x73, 0xe1 // ldrsb al r14 r3 minus 81 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r5_plus_31_PostIndex[] = {
  0xdf, 0x61, 0xd5, 0xe0 // ldrsb al r6 r5 plus 31 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r8_plus_47_PostIndex[] = {
  0xdf, 0xd2, 0xd8, 0xe0 // ldrsb al r13 r8 plus 47 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r11_plus_20_PostIndex[] = {
  0xd4, 0xe1, 0xdb, 0xe0 // ldrsb al r14 r11 plus 20 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r12_minus_52_PreIndex[] = {
  0xd4, 0xe3, 0x7c, 0xe1 // ldrsb al r14 r12 minus 52 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r0_plus_98_PreIndex[] = {
  0xd2, 0xd6, 0xf0, 0xe1 // ldrsb al r13 r0 plus 98 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r3_minus_249_PreIndex[] = {
  0xd9, 0xdf, 0x73, 0xe1 // ldrsb al r13 r3 minus 249 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r4_minus_147_PreIndex[] = {
  0xd3, 0x79, 0x74, 0xe1 // ldrsb al r7 r4 minus 147 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r1_plus_246_PostIndex[] = {
  0xd6, 0xdf, 0xd1, 0xe0 // ldrsb al r13 r1 plus 246 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r1_minus_70_PreIndex[] = {
  0xd6, 0xd4, 0x71, 0xe1 // ldrsb al r13 r1 minus 70 PreIndex
};
const byte kInstruction_ldrsb_al_r1_r14_plus_243_PreIndex[] = {
  0xd3, 0x1f, 0xfe, 0xe1 // ldrsb al r1 r14 plus 243 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r2_minus_92_PreIndex[] = {
  0xdc, 0x75, 0x72, 0xe1 // ldrsb al r7 r2 minus 92 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r3_plus_203_PreIndex[] = {
  0xdb, 0x7c, 0xf3, 0xe1 // ldrsb al r7 r3 plus 203 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r12_minus_28_PostIndex[] = {
  0xdc, 0x51, 0x5c, 0xe0 // ldrsb al r5 r12 minus 28 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r4_plus_149_PostIndex[] = {
  0xd5, 0xe9, 0xd4, 0xe0 // ldrsb al r14 r4 plus 149 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r8_plus_51_PostIndex[] = {
  0xd3, 0x23, 0xd8, 0xe0 // ldrsb al r2 r8 plus 51 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r2_plus_122_PreIndex[] = {
  0xda, 0xb7, 0xf2, 0xe1 // ldrsb al r11 r2 plus 122 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r8_plus_127_PostIndex[] = {
  0xdf, 0x37, 0xd8, 0xe0 // ldrsb al r3 r8 plus 127 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r4_plus_77_PreIndex[] = {
  0xdd, 0xa4, 0xf4, 0xe1 // ldrsb al r10 r4 plus 77 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r6_plus_245_PostIndex[] = {
  0xd5, 0xdf, 0xd6, 0xe0 // ldrsb al r13 r6 plus 245 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r3_minus_51_PostIndex[] = {
  0xd3, 0x13, 0x53, 0xe0 // ldrsb al r1 r3 minus 51 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r2_plus_55_PreIndex[] = {
  0xd7, 0xb3, 0xf2, 0xe1 // ldrsb al r11 r2 plus 55 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r3_minus_27_PostIndex[] = {
  0xdb, 0xa1, 0x53, 0xe0 // ldrsb al r10 r3 minus 27 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r11_minus_237_PreIndex[] = {
  0xdd, 0x6e, 0x7b, 0xe1 // ldrsb al r6 r11 minus 237 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r7_plus_135_PostIndex[] = {
  0xd7, 0xa8, 0xd7, 0xe0 // ldrsb al r10 r7 plus 135 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r9_minus_164_PostIndex[] = {
  0xd4, 0x2a, 0x59, 0xe0 // ldrsb al r2 r9 minus 164 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r9_plus_248_PreIndex[] = {
  0xd8, 0xdf, 0xf9, 0xe1 // ldrsb al r13 r9 plus 248 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r6_minus_126_PostIndex[] = {
  0xde, 0xd7, 0x56, 0xe0 // ldrsb al r13 r6 minus 126 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r0_plus_97_PreIndex[] = {
  0xd1, 0xb6, 0xf0, 0xe1 // ldrsb al r11 r0 plus 97 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r7_minus_51_PreIndex[] = {
  0xd3, 0x63, 0x77, 0xe1 // ldrsb al r6 r7 minus 51 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r10_minus_25_PostIndex[] = {
  0xd9, 0xc1, 0x5a, 0xe0 // ldrsb al r12 r10 minus 25 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r5_plus_101_PostIndex[] = {
  0xd5, 0x96, 0xd5, 0xe0 // ldrsb al r9 r5 plus 101 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r6_minus_123_PostIndex[] = {
  0xdb, 0x27, 0x56, 0xe0 // ldrsb al r2 r6 minus 123 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r11_minus_185_PostIndex[] = {
  0xd9, 0xdb, 0x5b, 0xe0 // ldrsb al r13 r11 minus 185 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r14_plus_127_PostIndex[] = {
  0xdf, 0x07, 0xde, 0xe0 // ldrsb al r0 r14 plus 127 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r6_minus_103_PreIndex[] = {
  0xd7, 0x86, 0x76, 0xe1 // ldrsb al r8 r6 minus 103 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r2_minus_116_PostIndex[] = {
  0xd4, 0x67, 0x52, 0xe0 // ldrsb al r6 r2 minus 116 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r5_plus_9_PostIndex[] = {
  0xd9, 0x30, 0xd5, 0xe0 // ldrsb al r3 r5 plus 9 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r9_minus_228_PostIndex[] = {
  0xd4, 0xbe, 0x59, 0xe0 // ldrsb al r11 r9 minus 228 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r1_plus_171_PreIndex[] = {
  0xdb, 0x9a, 0xf1, 0xe1 // ldrsb al r9 r1 plus 171 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r0_minus_105_PreIndex[] = {
  0xd9, 0xb6, 0x70, 0xe1 // ldrsb al r11 r0 minus 105 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r4_plus_188_PreIndex[] = {
  0xdc, 0x7b, 0xf4, 0xe1 // ldrsb al r7 r4 plus 188 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r5_plus_129_PreIndex[] = {
  0xd1, 0x88, 0xf5, 0xe1 // ldrsb al r8 r5 plus 129 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r5_plus_105_PostIndex[] = {
  0xd9, 0x66, 0xd5, 0xe0 // ldrsb al r6 r5 plus 105 PostIndex
};
const byte kInstruction_ldrsb_al_r4_r2_plus_39_PreIndex[] = {
  0xd7, 0x42, 0xf2, 0xe1 // ldrsb al r4 r2 plus 39 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r13_plus_164_PreIndex[] = {
  0xd4, 0xca, 0xfd, 0xe1 // ldrsb al r12 r13 plus 164 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r3_plus_215_PreIndex[] = {
  0xd7, 0xbd, 0xf3, 0xe1 // ldrsb al r11 r3 plus 215 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r14_minus_147_PostIndex[] = {
  0xd3, 0x39, 0x5e, 0xe0 // ldrsb al r3 r14 minus 147 PostIndex
};
const byte kInstruction_ldrsb_al_r13_r14_plus_88_PostIndex[] = {
  0xd8, 0xd5, 0xde, 0xe0 // ldrsb al r13 r14 plus 88 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r10_minus_159_PostIndex[] = {
  0xdf, 0x59, 0x5a, 0xe0 // ldrsb al r5 r10 minus 159 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r12_plus_219_PostIndex[] = {
  0xdb, 0x6d, 0xdc, 0xe0 // ldrsb al r6 r12 plus 219 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r12_minus_5_PostIndex[] = {
  0xd5, 0x90, 0x5c, 0xe0 // ldrsb al r9 r12 minus 5 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r13_minus_90_PreIndex[] = {
  0xda, 0xb5, 0x7d, 0xe1 // ldrsb al r11 r13 minus 90 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r2_minus_89_PostIndex[] = {
  0xd9, 0xb5, 0x52, 0xe0 // ldrsb al r11 r2 minus 89 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r13_plus_130_PostIndex[] = {
  0xd2, 0x28, 0xdd, 0xe0 // ldrsb al r2 r13 plus 130 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r11_plus_31_PreIndex[] = {
  0xdf, 0x61, 0xfb, 0xe1 // ldrsb al r6 r11 plus 31 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r14_plus_177_PostIndex[] = {
  0xd1, 0xcb, 0xde, 0xe0 // ldrsb al r12 r14 plus 177 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r9_plus_9_PreIndex[] = {
  0xd9, 0x00, 0xf9, 0xe1 // ldrsb al r0 r9 plus 9 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r7_plus_134_PreIndex[] = {
  0xd6, 0x98, 0xf7, 0xe1 // ldrsb al r9 r7 plus 134 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r4_minus_1_PostIndex[] = {
  0xd1, 0xb0, 0x54, 0xe0 // ldrsb al r11 r4 minus 1 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r4_minus_41_PreIndex[] = {
  0xd9, 0x52, 0x74, 0xe1 // ldrsb al r5 r4 minus 41 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r14_plus_31_PostIndex[] = {
  0xdf, 0x41, 0xde, 0xe0 // ldrsb al r4 r14 plus 31 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r2_plus_124_PostIndex[] = {
  0xdc, 0xc7, 0xd2, 0xe0 // ldrsb al r12 r2 plus 124 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r1_minus_160_PostIndex[] = {
  0xd0, 0x8a, 0x51, 0xe0 // ldrsb al r8 r1 minus 160 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r3_plus_151_PostIndex[] = {
  0xd7, 0xc9, 0xd3, 0xe0 // ldrsb al r12 r3 plus 151 PostIndex
};
const byte kInstruction_ldrsb_al_r11_r12_plus_12_PreIndex[] = {
  0xdc, 0xb0, 0xfc, 0xe1 // ldrsb al r11 r12 plus 12 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r9_plus_75_PostIndex[] = {
  0xdb, 0xc4, 0xd9, 0xe0 // ldrsb al r12 r9 plus 75 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r9_minus_80_PostIndex[] = {
  0xd0, 0x05, 0x59, 0xe0 // ldrsb al r0 r9 minus 80 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r2_minus_185_PreIndex[] = {
  0xd9, 0xcb, 0x72, 0xe1 // ldrsb al r12 r2 minus 185 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r2_minus_115_PostIndex[] = {
  0xd3, 0x57, 0x52, 0xe0 // ldrsb al r5 r2 minus 115 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r7_plus_82_PreIndex[] = {
  0xd2, 0x85, 0xf7, 0xe1 // ldrsb al r8 r7 plus 82 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r8_minus_119_PreIndex[] = {
  0xd7, 0x77, 0x78, 0xe1 // ldrsb al r7 r8 minus 119 PreIndex
};
const byte kInstruction_ldrsb_al_r14_r10_plus_38_PostIndex[] = {
  0xd6, 0xe2, 0xda, 0xe0 // ldrsb al r14 r10 plus 38 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r13_plus_96_PostIndex[] = {
  0xd0, 0x76, 0xdd, 0xe0 // ldrsb al r7 r13 plus 96 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r2_plus_253_PreIndex[] = {
  0xdd, 0x6f, 0xf2, 0xe1 // ldrsb al r6 r2 plus 253 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r10_plus_68_PreIndex[] = {
  0xd4, 0x74, 0xfa, 0xe1 // ldrsb al r7 r10 plus 68 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r9_plus_182_PostIndex[] = {
  0xd6, 0x0b, 0xd9, 0xe0 // ldrsb al r0 r9 plus 182 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r14_plus_153_PreIndex[] = {
  0xd9, 0x89, 0xfe, 0xe1 // ldrsb al r8 r14 plus 153 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r11_plus_69_PreIndex[] = {
  0xd5, 0x74, 0xfb, 0xe1 // ldrsb al r7 r11 plus 69 PreIndex
};
const byte kInstruction_ldrsb_al_r0_r4_plus_249_PreIndex[] = {
  0xd9, 0x0f, 0xf4, 0xe1 // ldrsb al r0 r4 plus 249 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r2_plus_65_PreIndex[] = {
  0xd1, 0x74, 0xf2, 0xe1 // ldrsb al r7 r2 plus 65 PreIndex
};
const byte kInstruction_ldrsb_al_r4_r10_plus_228_PostIndex[] = {
  0xd4, 0x4e, 0xda, 0xe0 // ldrsb al r4 r10 plus 228 PostIndex
};
const byte kInstruction_ldrsb_al_r5_r0_minus_94_PostIndex[] = {
  0xde, 0x55, 0x50, 0xe0 // ldrsb al r5 r0 minus 94 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r3_minus_131_PreIndex[] = {
  0xd3, 0xa8, 0x73, 0xe1 // ldrsb al r10 r3 minus 131 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r14_plus_191_PreIndex[] = {
  0xdf, 0x9b, 0xfe, 0xe1 // ldrsb al r9 r14 plus 191 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r1_minus_114_PostIndex[] = {
  0xd2, 0x37, 0x51, 0xe0 // ldrsb al r3 r1 minus 114 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r4_plus_123_PreIndex[] = {
  0xdb, 0x67, 0xf4, 0xe1 // ldrsb al r6 r4 plus 123 PreIndex
};
const byte kInstruction_ldrsb_al_r12_r6_minus_39_PreIndex[] = {
  0xd7, 0xc2, 0x76, 0xe1 // ldrsb al r12 r6 minus 39 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r11_minus_142_PostIndex[] = {
  0xde, 0x38, 0x5b, 0xe0 // ldrsb al r3 r11 minus 142 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r11_minus_216_PostIndex[] = {
  0xd8, 0x0d, 0x5b, 0xe0 // ldrsb al r0 r11 minus 216 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r5_minus_153_PostIndex[] = {
  0xd9, 0x99, 0x55, 0xe0 // ldrsb al r9 r5 minus 153 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r1_minus_49_PostIndex[] = {
  0xd1, 0xc3, 0x51, 0xe0 // ldrsb al r12 r1 minus 49 PostIndex
};
const byte kInstruction_ldrsb_al_r9_r6_plus_218_PreIndex[] = {
  0xda, 0x9d, 0xf6, 0xe1 // ldrsb al r9 r6 plus 218 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r6_minus_34_PostIndex[] = {
  0xd2, 0xb2, 0x56, 0xe0 // ldrsb al r11 r6 minus 34 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r7_plus_152_PreIndex[] = {
  0xd8, 0xa9, 0xf7, 0xe1 // ldrsb al r10 r7 plus 152 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r5_minus_180_PostIndex[] = {
  0xd4, 0x8b, 0x55, 0xe0 // ldrsb al r8 r5 minus 180 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r11_plus_236_PostIndex[] = {
  0xdc, 0x0e, 0xdb, 0xe0 // ldrsb al r0 r11 plus 236 PostIndex
};
const byte kInstruction_ldrsb_al_r3_r2_plus_107_PostIndex[] = {
  0xdb, 0x36, 0xd2, 0xe0 // ldrsb al r3 r2 plus 107 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r14_plus_207_PreIndex[] = {
  0xdf, 0x6c, 0xfe, 0xe1 // ldrsb al r6 r14 plus 207 PreIndex
};
const byte kInstruction_ldrsb_al_r11_r3_minus_146_PostIndex[] = {
  0xd2, 0xb9, 0x53, 0xe0 // ldrsb al r11 r3 minus 146 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r9_minus_145_PreIndex[] = {
  0xd1, 0x79, 0x79, 0xe1 // ldrsb al r7 r9 minus 145 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r2_minus_30_PostIndex[] = {
  0xde, 0x51, 0x52, 0xe0 // ldrsb al r5 r2 minus 30 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r5_plus_241_PostIndex[] = {
  0xd1, 0x6f, 0xd5, 0xe0 // ldrsb al r6 r5 plus 241 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r13_minus_218_PostIndex[] = {
  0xda, 0xad, 0x5d, 0xe0 // ldrsb al r10 r13 minus 218 PostIndex
};
const byte kInstruction_ldrsb_al_r8_r11_minus_173_PostIndex[] = {
  0xdd, 0x8a, 0x5b, 0xe0 // ldrsb al r8 r11 minus 173 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r3_minus_44_PostIndex[] = {
  0xdc, 0xa2, 0x53, 0xe0 // ldrsb al r10 r3 minus 44 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r3_minus_233_PostIndex[] = {
  0xd9, 0x1e, 0x53, 0xe0 // ldrsb al r1 r3 minus 233 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r7_minus_227_PostIndex[] = {
  0xd3, 0x6e, 0x57, 0xe0 // ldrsb al r6 r7 minus 227 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r0_plus_178_PreIndex[] = {
  0xd2, 0xcb, 0xf0, 0xe1 // ldrsb al r12 r0 plus 178 PreIndex
};
const byte kInstruction_ldrsb_al_r6_r10_plus_134_PreIndex[] = {
  0xd6, 0x68, 0xfa, 0xe1 // ldrsb al r6 r10 plus 134 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r10_minus_227_PostIndex[] = {
  0xd3, 0x2e, 0x5a, 0xe0 // ldrsb al r2 r10 minus 227 PostIndex
};
const byte kInstruction_ldrsb_al_r12_r9_minus_174_PostIndex[] = {
  0xde, 0xca, 0x59, 0xe0 // ldrsb al r12 r9 minus 174 PostIndex
};
const byte kInstruction_ldrsb_al_r6_r3_minus_109_PostIndex[] = {
  0xdd, 0x66, 0x53, 0xe0 // ldrsb al r6 r3 minus 109 PostIndex
};
const byte kInstruction_ldrsb_al_r1_r6_minus_30_PostIndex[] = {
  0xde, 0x11, 0x56, 0xe0 // ldrsb al r1 r6 minus 30 PostIndex
};
const byte kInstruction_ldrsb_al_r2_r9_plus_48_PreIndex[] = {
  0xd0, 0x23, 0xf9, 0xe1 // ldrsb al r2 r9 plus 48 PreIndex
};
const byte kInstruction_ldrsb_al_r13_r12_plus_4_PreIndex[] = {
  0xd4, 0xd0, 0xfc, 0xe1 // ldrsb al r13 r12 plus 4 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r8_plus_241_PostIndex[] = {
  0xd1, 0x2f, 0xd8, 0xe0 // ldrsb al r2 r8 plus 241 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r3_plus_135_PreIndex[] = {
  0xd7, 0xe8, 0xf3, 0xe1 // ldrsb al r14 r3 plus 135 PreIndex
};
const byte kInstruction_ldrsb_al_r3_r4_minus_161_PostIndex[] = {
  0xd1, 0x3a, 0x54, 0xe0 // ldrsb al r3 r4 minus 161 PostIndex
};
const byte kInstruction_ldrsb_al_r7_r1_plus_145_PreIndex[] = {
  0xd1, 0x79, 0xf1, 0xe1 // ldrsb al r7 r1 plus 145 PreIndex
};
const byte kInstruction_ldrsb_al_r8_r3_plus_105_PostIndex[] = {
  0xd9, 0x86, 0xd3, 0xe0 // ldrsb al r8 r3 plus 105 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r8_plus_218_PreIndex[] = {
  0xda, 0x0d, 0xf8, 0xe1 // ldrsb al r0 r8 plus 218 PreIndex
};
const byte kInstruction_ldrsb_al_r9_r3_plus_210_PostIndex[] = {
  0xd2, 0x9d, 0xd3, 0xe0 // ldrsb al r9 r3 plus 210 PostIndex
};
const byte kInstruction_ldrsb_al_r10_r1_plus_228_PreIndex[] = {
  0xd4, 0xae, 0xf1, 0xe1 // ldrsb al r10 r1 plus 228 PreIndex
};
const byte kInstruction_ldrsb_al_r2_r0_minus_85_PostIndex[] = {
  0xd5, 0x25, 0x50, 0xe0 // ldrsb al r2 r0 minus 85 PostIndex
};
const byte kInstruction_ldrsb_al_r0_r1_minus_62_PreIndex[] = {
  0xde, 0x03, 0x71, 0xe1 // ldrsb al r0 r1 minus 62 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r6_minus_150_PreIndex[] = {
  0xd6, 0x79, 0x76, 0xe1 // ldrsb al r7 r6 minus 150 PreIndex
};
const byte kInstruction_ldrsb_al_r5_r3_minus_113_PreIndex[] = {
  0xd1, 0x57, 0x73, 0xe1 // ldrsb al r5 r3 minus 113 PreIndex
};
const byte kInstruction_ldrsb_al_r10_r8_minus_210_PostIndex[] = {
  0xd2, 0xad, 0x58, 0xe0 // ldrsb al r10 r8 minus 210 PostIndex
};
const byte kInstruction_ldrsb_al_r14_r10_plus_56_PreIndex[] = {
  0xd8, 0xe3, 0xfa, 0xe1 // ldrsb al r14 r10 plus 56 PreIndex
};
const byte kInstruction_ldrsb_al_r7_r4_plus_55_PreIndex[] = {
  0xd7, 0x73, 0xf4, 0xe1 // ldrsb al r7 r4 plus 55 PreIndex
};
const TestResult kReferenceldrsb[] = {
  {
    ARRAY_SIZE(kInstruction_ldrsb_pl_r13_r0_plus_0_Offset),
    kInstruction_ldrsb_pl_r13_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r5_r3_plus_0_Offset),
    kInstruction_ldrsb_ge_r5_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r0_r4_plus_0_Offset),
    kInstruction_ldrsb_cc_r0_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r0_r0_plus_0_Offset),
    kInstruction_ldrsb_ge_r0_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_eq_r12_r3_plus_0_Offset),
    kInstruction_ldrsb_eq_r12_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r13_plus_0_Offset),
    kInstruction_ldrsb_al_r4_r13_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r8_r2_plus_0_Offset),
    kInstruction_ldrsb_mi_r8_r2_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r6_r9_plus_0_Offset),
    kInstruction_ldrsb_mi_r6_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r13_r11_plus_0_Offset),
    kInstruction_ldrsb_gt_r13_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cs_r0_r7_plus_0_Offset),
    kInstruction_ldrsb_cs_r0_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r7_r11_plus_0_Offset),
    kInstruction_ldrsb_ge_r7_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_pl_r11_r12_plus_0_Offset),
    kInstruction_ldrsb_pl_r11_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cs_r2_r12_plus_0_Offset),
    kInstruction_ldrsb_cs_r2_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r2_r14_plus_0_Offset),
    kInstruction_ldrsb_vc_r2_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r13_r6_plus_0_Offset),
    kInstruction_ldrsb_le_r13_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r1_r2_plus_0_Offset),
    kInstruction_ldrsb_ls_r1_r2_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r1_r6_plus_0_Offset),
    kInstruction_ldrsb_cc_r1_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_plus_0_Offset),
    kInstruction_ldrsb_al_r10_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r9_plus_0_Offset),
    kInstruction_ldrsb_al_r7_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r5_r3_plus_0_Offset),
    kInstruction_ldrsb_vs_r5_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_pl_r4_r4_plus_0_Offset),
    kInstruction_ldrsb_pl_r4_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r11_r9_plus_0_Offset),
    kInstruction_ldrsb_ne_r11_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r7_r14_plus_0_Offset),
    kInstruction_ldrsb_cc_r7_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r9_r3_plus_0_Offset),
    kInstruction_ldrsb_ne_r9_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r6_r14_plus_0_Offset),
    kInstruction_ldrsb_cc_r6_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r14_r14_plus_0_Offset),
    kInstruction_ldrsb_ne_r14_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r14_plus_0_Offset),
    kInstruction_ldrsb_al_r13_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r3_r1_plus_0_Offset),
    kInstruction_ldrsb_cc_r3_r1_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r1_r2_plus_0_Offset),
    kInstruction_ldrsb_ge_r1_r2_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_eq_r3_r4_plus_0_Offset),
    kInstruction_ldrsb_eq_r3_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r10_plus_0_Offset),
    kInstruction_ldrsb_al_r5_r10_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r1_r3_plus_0_Offset),
    kInstruction_ldrsb_mi_r1_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r1_r4_plus_0_Offset),
    kInstruction_ldrsb_gt_r1_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r12_plus_0_Offset),
    kInstruction_ldrsb_al_r7_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r14_r2_plus_0_Offset),
    kInstruction_ldrsb_ge_r14_r2_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r9_r7_plus_0_Offset),
    kInstruction_ldrsb_le_r9_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r14_plus_0_Offset),
    kInstruction_ldrsb_al_r9_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_hi_r10_r12_plus_0_Offset),
    kInstruction_ldrsb_hi_r10_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r6_r5_plus_0_Offset),
    kInstruction_ldrsb_le_r6_r5_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cs_r14_r12_plus_0_Offset),
    kInstruction_ldrsb_cs_r14_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r6_r9_plus_0_Offset),
    kInstruction_ldrsb_vc_r6_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r3_r9_plus_0_Offset),
    kInstruction_ldrsb_ne_r3_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r2_r9_plus_0_Offset),
    kInstruction_ldrsb_lt_r2_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r5_r11_plus_0_Offset),
    kInstruction_ldrsb_vc_r5_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r5_r1_plus_0_Offset),
    kInstruction_ldrsb_gt_r5_r1_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r4_plus_0_Offset),
    kInstruction_ldrsb_al_r12_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r11_r10_plus_0_Offset),
    kInstruction_ldrsb_ls_r11_r10_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_eq_r14_r7_plus_0_Offset),
    kInstruction_ldrsb_eq_r14_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r7_r0_plus_0_Offset),
    kInstruction_ldrsb_vc_r7_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r2_r6_plus_0_Offset),
    kInstruction_ldrsb_le_r2_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r2_r6_plus_0_Offset),
    kInstruction_ldrsb_gt_r2_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r6_plus_0_Offset),
    kInstruction_ldrsb_al_r6_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r10_r8_plus_0_Offset),
    kInstruction_ldrsb_ls_r10_r8_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r5_r8_plus_0_Offset),
    kInstruction_ldrsb_lt_r5_r8_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r13_r14_plus_0_Offset),
    kInstruction_ldrsb_vs_r13_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r9_r7_plus_0_Offset),
    kInstruction_ldrsb_gt_r9_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r8_r9_plus_0_Offset),
    kInstruction_ldrsb_cc_r8_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r2_r7_plus_0_Offset),
    kInstruction_ldrsb_le_r2_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r0_r1_plus_0_Offset),
    kInstruction_ldrsb_ge_r0_r1_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_eq_r10_r14_plus_0_Offset),
    kInstruction_ldrsb_eq_r10_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r3_r3_plus_0_Offset),
    kInstruction_ldrsb_ls_r3_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r11_r6_plus_0_Offset),
    kInstruction_ldrsb_mi_r11_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r14_r12_plus_0_Offset),
    kInstruction_ldrsb_ne_r14_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r1_r12_plus_0_Offset),
    kInstruction_ldrsb_vs_r1_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r0_r0_plus_0_Offset),
    kInstruction_ldrsb_ls_r0_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r12_r14_plus_0_Offset),
    kInstruction_ldrsb_lt_r12_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r13_r9_plus_0_Offset),
    kInstruction_ldrsb_lt_r13_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r13_r9_plus_0_Offset),
    kInstruction_ldrsb_ge_r13_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cs_r11_r0_plus_0_Offset),
    kInstruction_ldrsb_cs_r11_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_hi_r13_r11_plus_0_Offset),
    kInstruction_ldrsb_hi_r13_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cs_r13_r9_plus_0_Offset),
    kInstruction_ldrsb_cs_r13_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r10_r10_plus_0_Offset),
    kInstruction_ldrsb_ne_r10_r10_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r13_r9_plus_0_Offset),
    kInstruction_ldrsb_vc_r13_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r9_r3_plus_0_Offset),
    kInstruction_ldrsb_vc_r9_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_cc_r10_r4_plus_0_Offset),
    kInstruction_ldrsb_cc_r10_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_hi_r6_r6_plus_0_Offset),
    kInstruction_ldrsb_hi_r6_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r11_r1_plus_0_Offset),
    kInstruction_ldrsb_le_r11_r1_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r3_r5_plus_0_Offset),
    kInstruction_ldrsb_gt_r3_r5_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r0_r10_plus_0_Offset),
    kInstruction_ldrsb_lt_r0_r10_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r6_r0_plus_0_Offset),
    kInstruction_ldrsb_vs_r6_r0_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r8_r9_plus_0_Offset),
    kInstruction_ldrsb_vs_r8_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r9_r7_plus_0_Offset),
    kInstruction_ldrsb_mi_r9_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r12_r11_plus_0_Offset),
    kInstruction_ldrsb_vs_r12_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r11_r7_plus_0_Offset),
    kInstruction_ldrsb_vc_r11_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_hi_r11_r5_plus_0_Offset),
    kInstruction_ldrsb_hi_r11_r5_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_lt_r0_r11_plus_0_Offset),
    kInstruction_ldrsb_lt_r0_r11_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r11_r1_plus_0_Offset),
    kInstruction_ldrsb_ne_r11_r1_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ls_r5_r13_plus_0_Offset),
    kInstruction_ldrsb_ls_r5_r13_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r13_r3_plus_0_Offset),
    kInstruction_ldrsb_gt_r13_r3_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r12_r12_plus_0_Offset),
    kInstruction_ldrsb_vs_r12_r12_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_mi_r12_r7_plus_0_Offset),
    kInstruction_ldrsb_mi_r12_r7_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r3_r4_plus_0_Offset),
    kInstruction_ldrsb_le_r3_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r11_r10_plus_0_Offset),
    kInstruction_ldrsb_ne_r11_r10_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_gt_r6_r13_plus_0_Offset),
    kInstruction_ldrsb_gt_r6_r13_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_hi_r4_r8_plus_0_Offset),
    kInstruction_ldrsb_hi_r4_r8_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ge_r14_r5_plus_0_Offset),
    kInstruction_ldrsb_ge_r14_r5_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vc_r9_r6_plus_0_Offset),
    kInstruction_ldrsb_vc_r9_r6_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_le_r2_r9_plus_0_Offset),
    kInstruction_ldrsb_le_r2_r9_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_ne_r10_r4_plus_0_Offset),
    kInstruction_ldrsb_ne_r10_r4_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_vs_r10_r14_plus_0_Offset),
    kInstruction_ldrsb_vs_r10_r14_plus_0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_40_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_40_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_169_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_169_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_45_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_45_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_minus_237_Offset),
    kInstruction_ldrsb_al_r0_r14_minus_237_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_145_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_145_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_plus_69_Offset),
    kInstruction_ldrsb_al_r0_r13_plus_69_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_minus_37_Offset),
    kInstruction_ldrsb_al_r0_r8_minus_37_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_16_Offset),
    kInstruction_ldrsb_al_r0_r9_minus_16_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_89_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_89_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_174_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_174_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_177_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_177_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_10_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_80_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_80_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_minus_239_Offset),
    kInstruction_ldrsb_al_r0_r6_minus_239_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_146_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_146_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_minus_222_Offset),
    kInstruction_ldrsb_al_r0_r12_minus_222_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_212_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_212_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_plus_236_Offset),
    kInstruction_ldrsb_al_r0_r6_plus_236_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_46_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_46_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_117_Offset),
    kInstruction_ldrsb_al_r0_r9_minus_117_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_152_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_152_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_240_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_240_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_20_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_20_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_200_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_200_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_106_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_106_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_235_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_235_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_plus_188_Offset),
    kInstruction_ldrsb_al_r0_r11_plus_188_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_224_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_224_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_minus_218_Offset),
    kInstruction_ldrsb_al_r0_r10_minus_218_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_132_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_132_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_plus_210_Offset),
    kInstruction_ldrsb_al_r0_r12_plus_210_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_24_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_24_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_71_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_71_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_241_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_241_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_77_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_77_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_159_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_159_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_191_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_191_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_162_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_162_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_102_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_102_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_91_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_91_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_67_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_67_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_209_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_209_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_220_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_220_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_112_Offset),
    kInstruction_ldrsb_al_r0_r9_minus_112_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_95_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_95_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_minus_133_Offset),
    kInstruction_ldrsb_al_r0_r14_minus_133_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_70_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_70_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_191_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_191_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_minus_10_Offset),
    kInstruction_ldrsb_al_r0_r7_minus_10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_plus_10_Offset),
    kInstruction_ldrsb_al_r0_r10_plus_10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_78_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_78_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_252_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_252_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_plus_150_Offset),
    kInstruction_ldrsb_al_r0_r12_plus_150_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_69_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_69_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_12_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_115_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_115_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_233_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_233_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_plus_214_Offset),
    kInstruction_ldrsb_al_r0_r10_plus_214_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_123_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_123_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_plus_121_Offset),
    kInstruction_ldrsb_al_r0_r12_plus_121_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_93_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_93_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_239_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_239_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_56_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_56_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_1_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_plus_190_Offset),
    kInstruction_ldrsb_al_r0_r6_plus_190_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_plus_232_Offset),
    kInstruction_ldrsb_al_r0_r10_plus_232_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_232_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_232_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_210_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_210_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_208_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_208_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_221_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_221_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_77_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_77_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_plus_142_Offset),
    kInstruction_ldrsb_al_r0_r10_plus_142_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_14_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_29_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_29_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_plus_165_Offset),
    kInstruction_ldrsb_al_r0_r13_plus_165_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_minus_245_Offset),
    kInstruction_ldrsb_al_r0_r12_minus_245_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_minus_199_Offset),
    kInstruction_ldrsb_al_r0_r8_minus_199_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_34_Offset),
    kInstruction_ldrsb_al_r0_r9_minus_34_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_182_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_182_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_70_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_70_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_241_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_241_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_134_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_134_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_minus_155_Offset),
    kInstruction_ldrsb_al_r0_r6_minus_155_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_105_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_105_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_29_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_29_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_minus_223_Offset),
    kInstruction_ldrsb_al_r0_r1_minus_223_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_minus_141_Offset),
    kInstruction_ldrsb_al_r0_r10_minus_141_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_15_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_15_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_157_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_157_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_minus_122_Offset),
    kInstruction_ldrsb_al_r0_r10_minus_122_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_54_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_54_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_30_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_30_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_221_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_221_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_plus_34_Offset),
    kInstruction_ldrsb_al_r0_r12_plus_34_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_145_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_145_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_85_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_85_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_plus_64_Offset),
    kInstruction_ldrsb_al_r0_r6_plus_64_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_72_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_72_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_minus_97_Offset),
    kInstruction_ldrsb_al_r0_r10_minus_97_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_186_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_186_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_10_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_minus_236_Offset),
    kInstruction_ldrsb_al_r0_r6_minus_236_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_plus_73_Offset),
    kInstruction_ldrsb_al_r0_r13_plus_73_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_plus_112_Offset),
    kInstruction_ldrsb_al_r0_r13_plus_112_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_101_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_101_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_32_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_32_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_57_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_57_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_41_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_41_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_199_Offset),
    kInstruction_ldrsb_al_r0_r8_plus_199_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_208_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_208_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_63_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_63_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_minus_69_Offset),
    kInstruction_ldrsb_al_r0_r7_minus_69_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_19_Offset),
    kInstruction_ldrsb_al_r0_r8_plus_19_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_plus_128_Offset),
    kInstruction_ldrsb_al_r0_r6_plus_128_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_185_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_185_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_198_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_198_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_172_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_172_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_146_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_146_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_226_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_226_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_73_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_73_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_177_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_177_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_179_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_179_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_minus_70_Offset),
    kInstruction_ldrsb_al_r0_r7_minus_70_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_132_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_132_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_45_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_45_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_150_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_150_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_203_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_203_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_minus_107_Offset),
    kInstruction_ldrsb_al_r0_r7_minus_107_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_182_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_182_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_minus_112_Offset),
    kInstruction_ldrsb_al_r0_r14_minus_112_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_49_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_49_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_50_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_50_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_minus_153_Offset),
    kInstruction_ldrsb_al_r0_r14_minus_153_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_238_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_238_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_minus_131_Offset),
    kInstruction_ldrsb_al_r0_r10_minus_131_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_95_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_95_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_225_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_225_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_minus_180_Offset),
    kInstruction_ldrsb_al_r0_r8_minus_180_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_173_Offset),
    kInstruction_ldrsb_al_r0_r8_plus_173_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_161_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_161_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_plus_65_Offset),
    kInstruction_ldrsb_al_r0_r11_plus_65_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_52_Offset),
    kInstruction_ldrsb_al_r0_r8_plus_52_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_221_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_221_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_176_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_176_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_1_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_minus_139_Offset),
    kInstruction_ldrsb_al_r0_r8_minus_139_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_154_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_154_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_minus_54_Offset),
    kInstruction_ldrsb_al_r0_r5_minus_54_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_29_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_29_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_202_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_202_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_minus_136_Offset),
    kInstruction_ldrsb_al_r0_r12_minus_136_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_130_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_130_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_30_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_30_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_minus_136_Offset),
    kInstruction_ldrsb_al_r0_r1_minus_136_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_176_Offset),
    kInstruction_ldrsb_al_r0_r4_plus_176_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_141_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_141_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_196_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_196_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_55_Offset),
    kInstruction_ldrsb_al_r0_r9_minus_55_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_plus_99_Offset),
    kInstruction_ldrsb_al_r0_r11_plus_99_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_plus_169_Offset),
    kInstruction_ldrsb_al_r0_r12_plus_169_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_91_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_91_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r10_plus_93_Offset),
    kInstruction_ldrsb_al_r0_r10_plus_93_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_77_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_77_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_6_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_31_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_31_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_129_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_129_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_198_Offset),
    kInstruction_ldrsb_al_r0_r13_minus_198_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_33_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_33_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_16_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_16_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_minus_14_Offset),
    kInstruction_ldrsb_al_r0_r12_minus_14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_146_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_146_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_174_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_174_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_21_Offset),
    kInstruction_ldrsb_al_r0_r2_plus_21_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_202_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_202_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_36_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_36_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_179_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_179_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_84_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_84_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_plus_73_Offset),
    kInstruction_ldrsb_al_r0_r3_plus_73_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_122_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_122_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_8_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_plus_94_Offset),
    kInstruction_ldrsb_al_r0_r7_plus_94_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_217_Offset),
    kInstruction_ldrsb_al_r0_r8_plus_217_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_97_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_97_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_202_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_202_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_minus_28_Offset),
    kInstruction_ldrsb_al_r0_r14_minus_28_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_176_Offset),
    kInstruction_ldrsb_al_r0_r14_plus_176_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_148_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_148_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_204_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_204_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_minus_131_Offset),
    kInstruction_ldrsb_al_r0_r8_minus_131_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_plus_125_Offset),
    kInstruction_ldrsb_al_r0_r0_plus_125_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_255_Offset),
    kInstruction_ldrsb_al_r0_r4_minus_255_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_247_Offset),
    kInstruction_ldrsb_al_r0_r11_minus_247_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r0_minus_254_Offset),
    kInstruction_ldrsb_al_r0_r0_minus_254_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r3_minus_93_Offset),
    kInstruction_ldrsb_al_r0_r3_minus_93_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_137_Offset),
    kInstruction_ldrsb_al_r0_r2_minus_137_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r6_plus_70_Offset),
    kInstruction_ldrsb_al_r0_r6_plus_70_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_155_Offset),
    kInstruction_ldrsb_al_r0_r9_plus_155_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r7_minus_112_Offset),
    kInstruction_ldrsb_al_r0_r7_minus_112_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_135_Offset),
    kInstruction_ldrsb_al_r0_r5_plus_135_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_37_Offset),
    kInstruction_ldrsb_al_r0_r1_plus_37_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_180_PostIndex),
    kInstruction_ldrsb_al_r0_r2_minus_180_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r10_plus_36_PostIndex),
    kInstruction_ldrsb_al_r7_r10_plus_36_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_minus_99_PreIndex),
    kInstruction_ldrsb_al_r5_r3_minus_99_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_182_PostIndex),
    kInstruction_ldrsb_al_r0_r8_plus_182_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r12_plus_161_PreIndex),
    kInstruction_ldrsb_al_r13_r12_plus_161_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r13_minus_132_PreIndex),
    kInstruction_ldrsb_al_r4_r13_minus_132_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r3_minus_116_PostIndex),
    kInstruction_ldrsb_al_r11_r3_minus_116_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r14_minus_116_PreIndex),
    kInstruction_ldrsb_al_r11_r14_minus_116_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r1_plus_13_PostIndex),
    kInstruction_ldrsb_al_r7_r1_plus_13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r4_minus_198_PreIndex),
    kInstruction_ldrsb_al_r8_r4_minus_198_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_135_PostIndex),
    kInstruction_ldrsb_al_r0_r4_plus_135_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r3_minus_107_PreIndex),
    kInstruction_ldrsb_al_r11_r3_minus_107_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r6_plus_211_PostIndex),
    kInstruction_ldrsb_al_r13_r6_plus_211_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_plus_32_PostIndex),
    kInstruction_ldrsb_al_r11_r8_plus_32_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r6_plus_83_PreIndex),
    kInstruction_ldrsb_al_r7_r6_plus_83_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_79_PostIndex),
    kInstruction_ldrsb_al_r0_r13_minus_79_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r1_minus_124_PreIndex),
    kInstruction_ldrsb_al_r2_r1_minus_124_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r10_plus_91_PostIndex),
    kInstruction_ldrsb_al_r5_r10_plus_91_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r4_minus_138_PreIndex),
    kInstruction_ldrsb_al_r5_r4_minus_138_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r12_plus_78_PostIndex),
    kInstruction_ldrsb_al_r10_r12_plus_78_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_57_PreIndex),
    kInstruction_ldrsb_al_r0_r2_plus_57_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r0_plus_58_PostIndex),
    kInstruction_ldrsb_al_r2_r0_plus_58_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r5_plus_249_PreIndex),
    kInstruction_ldrsb_al_r10_r5_plus_249_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_minus_122_PostIndex),
    kInstruction_ldrsb_al_r11_r8_minus_122_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r4_minus_163_PreIndex),
    kInstruction_ldrsb_al_r5_r4_minus_163_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r14_plus_130_PreIndex),
    kInstruction_ldrsb_al_r6_r14_plus_130_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_175_PreIndex),
    kInstruction_ldrsb_al_r0_r9_plus_175_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r9_minus_79_PostIndex),
    kInstruction_ldrsb_al_r6_r9_minus_79_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_plus_14_PreIndex),
    kInstruction_ldrsb_al_r0_r2_plus_14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r4_minus_129_PreIndex),
    kInstruction_ldrsb_al_r9_r4_minus_129_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_minus_179_PreIndex),
    kInstruction_ldrsb_al_r11_r0_minus_179_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r11_minus_100_PreIndex),
    kInstruction_ldrsb_al_r2_r11_minus_100_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r11_minus_246_PostIndex),
    kInstruction_ldrsb_al_r3_r11_minus_246_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r4_minus_38_PostIndex),
    kInstruction_ldrsb_al_r1_r4_minus_38_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r14_plus_216_PreIndex),
    kInstruction_ldrsb_al_r12_r14_plus_216_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r5_minus_37_PreIndex),
    kInstruction_ldrsb_al_r13_r5_minus_37_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r10_minus_90_PostIndex),
    kInstruction_ldrsb_al_r9_r10_minus_90_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r14_plus_115_PostIndex),
    kInstruction_ldrsb_al_r1_r14_plus_115_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_plus_194_PostIndex),
    kInstruction_ldrsb_al_r0_r13_plus_194_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r14_minus_162_PreIndex),
    kInstruction_ldrsb_al_r13_r14_minus_162_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r3_minus_251_PostIndex),
    kInstruction_ldrsb_al_r2_r3_minus_251_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r3_plus_190_PostIndex),
    kInstruction_ldrsb_al_r2_r3_plus_190_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r13_minus_47_PostIndex),
    kInstruction_ldrsb_al_r0_r13_minus_47_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r4_minus_59_PostIndex),
    kInstruction_ldrsb_al_r14_r4_minus_59_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r0_plus_62_PreIndex),
    kInstruction_ldrsb_al_r10_r0_plus_62_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r14_minus_239_PostIndex),
    kInstruction_ldrsb_al_r1_r14_minus_239_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r3_minus_29_PostIndex),
    kInstruction_ldrsb_al_r4_r3_minus_29_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r14_plus_174_PreIndex),
    kInstruction_ldrsb_al_r4_r14_plus_174_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r5_minus_167_PostIndex),
    kInstruction_ldrsb_al_r7_r5_minus_167_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r11_minus_46_PreIndex),
    kInstruction_ldrsb_al_r5_r11_minus_46_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r13_plus_13_PostIndex),
    kInstruction_ldrsb_al_r3_r13_plus_13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r7_plus_10_PreIndex),
    kInstruction_ldrsb_al_r3_r7_plus_10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r5_minus_95_PostIndex),
    kInstruction_ldrsb_al_r4_r5_minus_95_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_minus_17_PostIndex),
    kInstruction_ldrsb_al_r11_r8_minus_17_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r10_plus_72_PostIndex),
    kInstruction_ldrsb_al_r2_r10_plus_72_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r12_minus_6_PostIndex),
    kInstruction_ldrsb_al_r0_r12_minus_6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r4_plus_232_PostIndex),
    kInstruction_ldrsb_al_r14_r4_plus_232_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r9_plus_62_PostIndex),
    kInstruction_ldrsb_al_r6_r9_plus_62_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r14_minus_251_PreIndex),
    kInstruction_ldrsb_al_r6_r14_minus_251_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_plus_213_PostIndex),
    kInstruction_ldrsb_al_r10_r3_plus_213_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r5_plus_95_PreIndex),
    kInstruction_ldrsb_al_r4_r5_plus_95_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r12_plus_90_PreIndex),
    kInstruction_ldrsb_al_r13_r12_plus_90_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r8_minus_117_PostIndex),
    kInstruction_ldrsb_al_r1_r8_minus_117_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r3_minus_9_PreIndex),
    kInstruction_ldrsb_al_r13_r3_minus_9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r4_plus_174_PostIndex),
    kInstruction_ldrsb_al_r6_r4_plus_174_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r10_plus_85_PostIndex),
    kInstruction_ldrsb_al_r14_r10_plus_85_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_plus_77_PostIndex),
    kInstruction_ldrsb_al_r10_r3_plus_77_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r12_minus_124_PostIndex),
    kInstruction_ldrsb_al_r8_r12_minus_124_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r2_minus_66_PostIndex),
    kInstruction_ldrsb_al_r0_r2_minus_66_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r0_minus_121_PreIndex),
    kInstruction_ldrsb_al_r6_r0_minus_121_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r4_minus_10_PostIndex),
    kInstruction_ldrsb_al_r1_r4_minus_10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r5_plus_35_PreIndex),
    kInstruction_ldrsb_al_r0_r5_plus_35_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r2_plus_76_PostIndex),
    kInstruction_ldrsb_al_r11_r2_plus_76_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r13_plus_162_PreIndex),
    kInstruction_ldrsb_al_r4_r13_plus_162_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r4_plus_219_PreIndex),
    kInstruction_ldrsb_al_r9_r4_plus_219_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r3_plus_92_PreIndex),
    kInstruction_ldrsb_al_r2_r3_plus_92_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r0_plus_173_PostIndex),
    kInstruction_ldrsb_al_r4_r0_plus_173_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_minus_92_PreIndex),
    kInstruction_ldrsb_al_r0_r4_minus_92_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r4_plus_198_PreIndex),
    kInstruction_ldrsb_al_r1_r4_plus_198_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r11_plus_164_PreIndex),
    kInstruction_ldrsb_al_r4_r11_plus_164_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_plus_29_PreIndex),
    kInstruction_ldrsb_al_r10_r3_plus_29_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_129_PreIndex),
    kInstruction_ldrsb_al_r0_r4_plus_129_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r8_plus_120_PreIndex),
    kInstruction_ldrsb_al_r14_r8_plus_120_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r10_plus_187_PostIndex),
    kInstruction_ldrsb_al_r11_r10_plus_187_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r0_plus_69_PostIndex),
    kInstruction_ldrsb_al_r2_r0_plus_69_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r7_plus_130_PreIndex),
    kInstruction_ldrsb_al_r9_r7_plus_130_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r5_minus_59_PreIndex),
    kInstruction_ldrsb_al_r10_r5_minus_59_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r2_plus_196_PreIndex),
    kInstruction_ldrsb_al_r13_r2_plus_196_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r6_plus_27_PreIndex),
    kInstruction_ldrsb_al_r12_r6_plus_27_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r0_plus_30_PostIndex),
    kInstruction_ldrsb_al_r9_r0_plus_30_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_plus_208_PostIndex),
    kInstruction_ldrsb_al_r8_r11_plus_208_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r10_plus_150_PostIndex),
    kInstruction_ldrsb_al_r6_r10_plus_150_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r9_plus_115_PostIndex),
    kInstruction_ldrsb_al_r3_r9_plus_115_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r14_minus_65_PreIndex),
    kInstruction_ldrsb_al_r2_r14_minus_65_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r9_plus_150_PreIndex),
    kInstruction_ldrsb_al_r12_r9_plus_150_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r11_plus_153_PostIndex),
    kInstruction_ldrsb_al_r2_r11_plus_153_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r11_minus_80_PostIndex),
    kInstruction_ldrsb_al_r4_r11_minus_80_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_minus_164_PostIndex),
    kInstruction_ldrsb_al_r8_r11_minus_164_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r9_plus_140_PreIndex),
    kInstruction_ldrsb_al_r8_r9_plus_140_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r1_minus_237_PreIndex),
    kInstruction_ldrsb_al_r4_r1_minus_237_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r4_plus_16_PostIndex),
    kInstruction_ldrsb_al_r9_r4_plus_16_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r6_plus_248_PreIndex),
    kInstruction_ldrsb_al_r13_r6_plus_248_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r12_plus_196_PostIndex),
    kInstruction_ldrsb_al_r9_r12_plus_196_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r1_plus_68_PostIndex),
    kInstruction_ldrsb_al_r2_r1_plus_68_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r2_minus_106_PreIndex),
    kInstruction_ldrsb_al_r1_r2_minus_106_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r9_minus_21_PreIndex),
    kInstruction_ldrsb_al_r3_r9_minus_21_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r3_plus_39_PreIndex),
    kInstruction_ldrsb_al_r13_r3_plus_39_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r11_plus_75_PostIndex),
    kInstruction_ldrsb_al_r2_r11_plus_75_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_minus_136_PostIndex),
    kInstruction_ldrsb_al_r5_r3_minus_136_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r13_minus_229_PreIndex),
    kInstruction_ldrsb_al_r12_r13_minus_229_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r5_plus_130_PostIndex),
    kInstruction_ldrsb_al_r9_r5_plus_130_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r5_plus_206_PostIndex),
    kInstruction_ldrsb_al_r2_r5_plus_206_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r6_minus_6_PreIndex),
    kInstruction_ldrsb_al_r4_r6_minus_6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r13_plus_113_PreIndex),
    kInstruction_ldrsb_al_r14_r13_plus_113_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r5_plus_128_PostIndex),
    kInstruction_ldrsb_al_r1_r5_plus_128_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r4_plus_171_PostIndex),
    kInstruction_ldrsb_al_r2_r4_plus_171_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r0_minus_125_PostIndex),
    kInstruction_ldrsb_al_r6_r0_minus_125_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r12_plus_224_PostIndex),
    kInstruction_ldrsb_al_r14_r12_plus_224_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r6_minus_185_PreIndex),
    kInstruction_ldrsb_al_r12_r6_minus_185_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r0_plus_143_PostIndex),
    kInstruction_ldrsb_al_r6_r0_plus_143_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r13_plus_219_PostIndex),
    kInstruction_ldrsb_al_r4_r13_plus_219_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r0_plus_187_PostIndex),
    kInstruction_ldrsb_al_r13_r0_plus_187_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r0_plus_103_PreIndex),
    kInstruction_ldrsb_al_r14_r0_plus_103_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_minus_73_PostIndex),
    kInstruction_ldrsb_al_r5_r2_minus_73_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r11_plus_109_PostIndex),
    kInstruction_ldrsb_al_r3_r11_plus_109_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r5_plus_22_PreIndex),
    kInstruction_ldrsb_al_r2_r5_plus_22_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r5_minus_123_PostIndex),
    kInstruction_ldrsb_al_r13_r5_minus_123_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r5_minus_133_PreIndex),
    kInstruction_ldrsb_al_r14_r5_minus_133_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r11_minus_226_PostIndex),
    kInstruction_ldrsb_al_r10_r11_minus_226_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r6_plus_175_PostIndex),
    kInstruction_ldrsb_al_r3_r6_plus_175_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_6_PreIndex),
    kInstruction_ldrsb_al_r0_r11_minus_6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r1_plus_170_PostIndex),
    kInstruction_ldrsb_al_r7_r1_plus_170_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r7_plus_107_PostIndex),
    kInstruction_ldrsb_al_r12_r7_plus_107_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_minus_109_PostIndex),
    kInstruction_ldrsb_al_r8_r11_minus_109_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r0_minus_93_PreIndex),
    kInstruction_ldrsb_al_r8_r0_minus_93_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r3_minus_152_PostIndex),
    kInstruction_ldrsb_al_r9_r3_minus_152_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r12_minus_233_PostIndex),
    kInstruction_ldrsb_al_r9_r12_minus_233_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_minus_122_PostIndex),
    kInstruction_ldrsb_al_r5_r2_minus_122_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r9_plus_248_PostIndex),
    kInstruction_ldrsb_al_r2_r9_plus_248_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r14_minus_137_PreIndex),
    kInstruction_ldrsb_al_r2_r14_minus_137_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r12_plus_19_PreIndex),
    kInstruction_ldrsb_al_r10_r12_plus_19_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r10_plus_116_PostIndex),
    kInstruction_ldrsb_al_r7_r10_plus_116_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_minus_46_PreIndex),
    kInstruction_ldrsb_al_r11_r8_minus_46_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r9_minus_16_PreIndex),
    kInstruction_ldrsb_al_r4_r9_minus_16_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r9_minus_74_PostIndex),
    kInstruction_ldrsb_al_r8_r9_minus_74_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r9_minus_7_PostIndex),
    kInstruction_ldrsb_al_r13_r9_minus_7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r6_plus_100_PostIndex),
    kInstruction_ldrsb_al_r7_r6_plus_100_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r1_minus_217_PostIndex),
    kInstruction_ldrsb_al_r13_r1_minus_217_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r0_plus_219_PreIndex),
    kInstruction_ldrsb_al_r5_r0_plus_219_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r1_minus_148_PreIndex),
    kInstruction_ldrsb_al_r9_r1_minus_148_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_211_PreIndex),
    kInstruction_ldrsb_al_r0_r8_plus_211_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r6_plus_82_PreIndex),
    kInstruction_ldrsb_al_r9_r6_plus_82_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_minus_222_PreIndex),
    kInstruction_ldrsb_al_r0_r1_minus_222_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r1_plus_225_PostIndex),
    kInstruction_ldrsb_al_r3_r1_plus_225_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_minus_28_PostIndex),
    kInstruction_ldrsb_al_r5_r2_minus_28_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r5_minus_24_PostIndex),
    kInstruction_ldrsb_al_r7_r5_minus_24_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r8_minus_55_PreIndex),
    kInstruction_ldrsb_al_r4_r8_minus_55_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r14_minus_90_PostIndex),
    kInstruction_ldrsb_al_r6_r14_minus_90_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r0_minus_158_PreIndex),
    kInstruction_ldrsb_al_r3_r0_minus_158_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r8_plus_239_PostIndex),
    kInstruction_ldrsb_al_r10_r8_plus_239_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r5_plus_185_PostIndex),
    kInstruction_ldrsb_al_r4_r5_plus_185_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_minus_34_PreIndex),
    kInstruction_ldrsb_al_r5_r3_minus_34_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_minus_129_PostIndex),
    kInstruction_ldrsb_al_r11_r0_minus_129_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r9_minus_175_PreIndex),
    kInstruction_ldrsb_al_r2_r9_minus_175_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r13_plus_87_PreIndex),
    kInstruction_ldrsb_al_r2_r13_plus_87_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r7_plus_34_PostIndex),
    kInstruction_ldrsb_al_r8_r7_plus_34_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r1_minus_124_PostIndex),
    kInstruction_ldrsb_al_r3_r1_minus_124_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r0_minus_163_PostIndex),
    kInstruction_ldrsb_al_r12_r0_minus_163_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r11_minus_88_PostIndex),
    kInstruction_ldrsb_al_r9_r11_minus_88_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r13_minus_143_PostIndex),
    kInstruction_ldrsb_al_r11_r13_minus_143_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r12_plus_247_PostIndex),
    kInstruction_ldrsb_al_r6_r12_plus_247_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r1_plus_47_PostIndex),
    kInstruction_ldrsb_al_r4_r1_plus_47_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_plus_228_PreIndex),
    kInstruction_ldrsb_al_r5_r2_plus_228_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r13_minus_200_PreIndex),
    kInstruction_ldrsb_al_r6_r13_minus_200_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r0_plus_188_PreIndex),
    kInstruction_ldrsb_al_r10_r0_plus_188_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r9_plus_19_PostIndex),
    kInstruction_ldrsb_al_r12_r9_plus_19_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r6_minus_184_PostIndex),
    kInstruction_ldrsb_al_r3_r6_minus_184_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r10_plus_229_PostIndex),
    kInstruction_ldrsb_al_r12_r10_plus_229_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_minus_179_PreIndex),
    kInstruction_ldrsb_al_r5_r3_minus_179_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r9_plus_120_PostIndex),
    kInstruction_ldrsb_al_r12_r9_plus_120_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r10_plus_143_PreIndex),
    kInstruction_ldrsb_al_r9_r10_plus_143_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r2_minus_148_PostIndex),
    kInstruction_ldrsb_al_r1_r2_minus_148_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r1_plus_210_PreIndex),
    kInstruction_ldrsb_al_r7_r1_plus_210_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r12_plus_208_PreIndex),
    kInstruction_ldrsb_al_r5_r12_plus_208_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r8_plus_6_PreIndex),
    kInstruction_ldrsb_al_r1_r8_plus_6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r6_minus_106_PreIndex),
    kInstruction_ldrsb_al_r9_r6_minus_106_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r9_minus_59_PostIndex),
    kInstruction_ldrsb_al_r1_r9_minus_59_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r11_minus_18_PreIndex),
    kInstruction_ldrsb_al_r6_r11_minus_18_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r7_plus_19_PreIndex),
    kInstruction_ldrsb_al_r2_r7_plus_19_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r5_minus_229_PreIndex),
    kInstruction_ldrsb_al_r12_r5_minus_229_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r5_minus_60_PostIndex),
    kInstruction_ldrsb_al_r8_r5_minus_60_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r8_minus_125_PreIndex),
    kInstruction_ldrsb_al_r9_r8_minus_125_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r13_plus_137_PostIndex),
    kInstruction_ldrsb_al_r14_r13_plus_137_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r1_plus_1_PostIndex),
    kInstruction_ldrsb_al_r9_r1_plus_1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r2_plus_230_PostIndex),
    kInstruction_ldrsb_al_r6_r2_plus_230_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_plus_218_PostIndex),
    kInstruction_ldrsb_al_r11_r0_plus_218_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r10_plus_125_PostIndex),
    kInstruction_ldrsb_al_r8_r10_plus_125_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r4_plus_138_PostIndex),
    kInstruction_ldrsb_al_r1_r4_plus_138_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r9_minus_66_PreIndex),
    kInstruction_ldrsb_al_r10_r9_minus_66_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r11_plus_25_PreIndex),
    kInstruction_ldrsb_al_r14_r11_plus_25_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r3_minus_76_PostIndex),
    kInstruction_ldrsb_al_r9_r3_minus_76_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r14_plus_8_PostIndex),
    kInstruction_ldrsb_al_r9_r14_plus_8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r14_plus_67_PostIndex),
    kInstruction_ldrsb_al_r3_r14_plus_67_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r0_minus_39_PreIndex),
    kInstruction_ldrsb_al_r3_r0_minus_39_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r1_minus_17_PreIndex),
    kInstruction_ldrsb_al_r8_r1_minus_17_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r11_minus_223_PreIndex),
    kInstruction_ldrsb_al_r14_r11_minus_223_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r10_plus_99_PreIndex),
    kInstruction_ldrsb_al_r7_r10_plus_99_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r11_minus_12_PostIndex),
    kInstruction_ldrsb_al_r14_r11_minus_12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r10_minus_235_PostIndex),
    kInstruction_ldrsb_al_r13_r10_minus_235_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r13_minus_167_PreIndex),
    kInstruction_ldrsb_al_r3_r13_minus_167_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r11_plus_222_PostIndex),
    kInstruction_ldrsb_al_r13_r11_plus_222_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r4_minus_20_PreIndex),
    kInstruction_ldrsb_al_r2_r4_minus_20_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r3_plus_185_PostIndex),
    kInstruction_ldrsb_al_r1_r3_plus_185_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_plus_115_PostIndex),
    kInstruction_ldrsb_al_r0_r1_plus_115_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r0_plus_169_PreIndex),
    kInstruction_ldrsb_al_r2_r0_plus_169_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r5_plus_121_PostIndex),
    kInstruction_ldrsb_al_r11_r5_plus_121_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r12_minus_114_PostIndex),
    kInstruction_ldrsb_al_r5_r12_minus_114_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r13_minus_71_PostIndex),
    kInstruction_ldrsb_al_r14_r13_minus_71_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r10_plus_127_PreIndex),
    kInstruction_ldrsb_al_r12_r10_plus_127_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_minus_125_PostIndex),
    kInstruction_ldrsb_al_r8_r11_minus_125_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r9_plus_239_PostIndex),
    kInstruction_ldrsb_al_r13_r9_plus_239_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r1_plus_74_PreIndex),
    kInstruction_ldrsb_al_r3_r1_plus_74_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r7_minus_229_PostIndex),
    kInstruction_ldrsb_al_r8_r7_minus_229_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r1_plus_240_PostIndex),
    kInstruction_ldrsb_al_r8_r1_plus_240_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r4_minus_51_PreIndex),
    kInstruction_ldrsb_al_r2_r4_minus_51_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r9_minus_103_PreIndex),
    kInstruction_ldrsb_al_r13_r9_minus_103_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r6_minus_138_PostIndex),
    kInstruction_ldrsb_al_r4_r6_minus_138_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_minus_145_PostIndex),
    kInstruction_ldrsb_al_r11_r0_minus_145_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r3_plus_232_PostIndex),
    kInstruction_ldrsb_al_r6_r3_plus_232_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r2_plus_117_PreIndex),
    kInstruction_ldrsb_al_r14_r2_plus_117_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r6_plus_224_PreIndex),
    kInstruction_ldrsb_al_r5_r6_plus_224_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r2_minus_192_PostIndex),
    kInstruction_ldrsb_al_r7_r2_minus_192_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r8_plus_250_PreIndex),
    kInstruction_ldrsb_al_r14_r8_plus_250_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_minus_34_PreIndex),
    kInstruction_ldrsb_al_r8_r11_minus_34_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r11_minus_153_PreIndex),
    kInstruction_ldrsb_al_r12_r11_minus_153_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r0_minus_61_PreIndex),
    kInstruction_ldrsb_al_r4_r0_minus_61_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r12_plus_158_PostIndex),
    kInstruction_ldrsb_al_r3_r12_plus_158_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r12_plus_212_PreIndex),
    kInstruction_ldrsb_al_r6_r12_plus_212_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r10_plus_189_PostIndex),
    kInstruction_ldrsb_al_r6_r10_plus_189_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r6_plus_234_PostIndex),
    kInstruction_ldrsb_al_r2_r6_plus_234_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r11_minus_134_PostIndex),
    kInstruction_ldrsb_al_r10_r11_minus_134_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r6_minus_240_PostIndex),
    kInstruction_ldrsb_al_r11_r6_minus_240_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r10_minus_162_PreIndex),
    kInstruction_ldrsb_al_r1_r10_minus_162_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r3_plus_235_PostIndex),
    kInstruction_ldrsb_al_r8_r3_plus_235_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r12_plus_192_PreIndex),
    kInstruction_ldrsb_al_r5_r12_plus_192_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r3_minus_13_PostIndex),
    kInstruction_ldrsb_al_r11_r3_minus_13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r5_plus_192_PostIndex),
    kInstruction_ldrsb_al_r3_r5_plus_192_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r5_plus_75_PreIndex),
    kInstruction_ldrsb_al_r1_r5_plus_75_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r7_plus_9_PostIndex),
    kInstruction_ldrsb_al_r1_r7_plus_9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r14_plus_103_PreIndex),
    kInstruction_ldrsb_al_r1_r14_plus_103_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r5_plus_254_PostIndex),
    kInstruction_ldrsb_al_r4_r5_plus_254_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r3_plus_219_PreIndex),
    kInstruction_ldrsb_al_r7_r3_plus_219_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r7_minus_233_PreIndex),
    kInstruction_ldrsb_al_r6_r7_minus_233_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r6_plus_93_PostIndex),
    kInstruction_ldrsb_al_r7_r6_plus_93_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r14_plus_15_PreIndex),
    kInstruction_ldrsb_al_r5_r14_plus_15_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r2_plus_51_PreIndex),
    kInstruction_ldrsb_al_r4_r2_plus_51_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r7_plus_233_PostIndex),
    kInstruction_ldrsb_al_r12_r7_plus_233_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_plus_219_PostIndex),
    kInstruction_ldrsb_al_r11_r8_plus_219_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r10_minus_189_PostIndex),
    kInstruction_ldrsb_al_r1_r10_minus_189_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r13_minus_101_PostIndex),
    kInstruction_ldrsb_al_r4_r13_minus_101_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r12_minus_46_PreIndex),
    kInstruction_ldrsb_al_r4_r12_minus_46_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r12_minus_195_PreIndex),
    kInstruction_ldrsb_al_r14_r12_minus_195_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r2_minus_141_PreIndex),
    kInstruction_ldrsb_al_r8_r2_minus_141_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_plus_191_PostIndex),
    kInstruction_ldrsb_al_r5_r3_plus_191_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r1_plus_216_PostIndex),
    kInstruction_ldrsb_al_r7_r1_plus_216_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r13_minus_87_PostIndex),
    kInstruction_ldrsb_al_r6_r13_minus_87_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r8_minus_39_PreIndex),
    kInstruction_ldrsb_al_r11_r8_minus_39_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r6_minus_181_PreIndex),
    kInstruction_ldrsb_al_r1_r6_minus_181_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r4_plus_162_PostIndex),
    kInstruction_ldrsb_al_r6_r4_plus_162_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r3_minus_81_PreIndex),
    kInstruction_ldrsb_al_r14_r3_minus_81_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r5_plus_31_PostIndex),
    kInstruction_ldrsb_al_r6_r5_plus_31_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r8_plus_47_PostIndex),
    kInstruction_ldrsb_al_r13_r8_plus_47_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r11_plus_20_PostIndex),
    kInstruction_ldrsb_al_r14_r11_plus_20_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r12_minus_52_PreIndex),
    kInstruction_ldrsb_al_r14_r12_minus_52_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r0_plus_98_PreIndex),
    kInstruction_ldrsb_al_r13_r0_plus_98_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r3_minus_249_PreIndex),
    kInstruction_ldrsb_al_r13_r3_minus_249_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r4_minus_147_PreIndex),
    kInstruction_ldrsb_al_r7_r4_minus_147_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r1_plus_246_PostIndex),
    kInstruction_ldrsb_al_r13_r1_plus_246_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r1_minus_70_PreIndex),
    kInstruction_ldrsb_al_r13_r1_minus_70_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r14_plus_243_PreIndex),
    kInstruction_ldrsb_al_r1_r14_plus_243_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r2_minus_92_PreIndex),
    kInstruction_ldrsb_al_r7_r2_minus_92_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r3_plus_203_PreIndex),
    kInstruction_ldrsb_al_r7_r3_plus_203_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r12_minus_28_PostIndex),
    kInstruction_ldrsb_al_r5_r12_minus_28_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r4_plus_149_PostIndex),
    kInstruction_ldrsb_al_r14_r4_plus_149_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r8_plus_51_PostIndex),
    kInstruction_ldrsb_al_r2_r8_plus_51_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r2_plus_122_PreIndex),
    kInstruction_ldrsb_al_r11_r2_plus_122_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r8_plus_127_PostIndex),
    kInstruction_ldrsb_al_r3_r8_plus_127_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r4_plus_77_PreIndex),
    kInstruction_ldrsb_al_r10_r4_plus_77_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r6_plus_245_PostIndex),
    kInstruction_ldrsb_al_r13_r6_plus_245_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r3_minus_51_PostIndex),
    kInstruction_ldrsb_al_r1_r3_minus_51_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r2_plus_55_PreIndex),
    kInstruction_ldrsb_al_r11_r2_plus_55_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_minus_27_PostIndex),
    kInstruction_ldrsb_al_r10_r3_minus_27_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r11_minus_237_PreIndex),
    kInstruction_ldrsb_al_r6_r11_minus_237_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r7_plus_135_PostIndex),
    kInstruction_ldrsb_al_r10_r7_plus_135_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r9_minus_164_PostIndex),
    kInstruction_ldrsb_al_r2_r9_minus_164_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r9_plus_248_PreIndex),
    kInstruction_ldrsb_al_r13_r9_plus_248_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r6_minus_126_PostIndex),
    kInstruction_ldrsb_al_r13_r6_minus_126_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_plus_97_PreIndex),
    kInstruction_ldrsb_al_r11_r0_plus_97_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r7_minus_51_PreIndex),
    kInstruction_ldrsb_al_r6_r7_minus_51_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r10_minus_25_PostIndex),
    kInstruction_ldrsb_al_r12_r10_minus_25_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r5_plus_101_PostIndex),
    kInstruction_ldrsb_al_r9_r5_plus_101_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r6_minus_123_PostIndex),
    kInstruction_ldrsb_al_r2_r6_minus_123_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r11_minus_185_PostIndex),
    kInstruction_ldrsb_al_r13_r11_minus_185_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r14_plus_127_PostIndex),
    kInstruction_ldrsb_al_r0_r14_plus_127_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r6_minus_103_PreIndex),
    kInstruction_ldrsb_al_r8_r6_minus_103_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r2_minus_116_PostIndex),
    kInstruction_ldrsb_al_r6_r2_minus_116_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r5_plus_9_PostIndex),
    kInstruction_ldrsb_al_r3_r5_plus_9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r9_minus_228_PostIndex),
    kInstruction_ldrsb_al_r11_r9_minus_228_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r1_plus_171_PreIndex),
    kInstruction_ldrsb_al_r9_r1_plus_171_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r0_minus_105_PreIndex),
    kInstruction_ldrsb_al_r11_r0_minus_105_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r4_plus_188_PreIndex),
    kInstruction_ldrsb_al_r7_r4_plus_188_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r5_plus_129_PreIndex),
    kInstruction_ldrsb_al_r8_r5_plus_129_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r5_plus_105_PostIndex),
    kInstruction_ldrsb_al_r6_r5_plus_105_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r2_plus_39_PreIndex),
    kInstruction_ldrsb_al_r4_r2_plus_39_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r13_plus_164_PreIndex),
    kInstruction_ldrsb_al_r12_r13_plus_164_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r3_plus_215_PreIndex),
    kInstruction_ldrsb_al_r11_r3_plus_215_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r14_minus_147_PostIndex),
    kInstruction_ldrsb_al_r3_r14_minus_147_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r14_plus_88_PostIndex),
    kInstruction_ldrsb_al_r13_r14_plus_88_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r10_minus_159_PostIndex),
    kInstruction_ldrsb_al_r5_r10_minus_159_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r12_plus_219_PostIndex),
    kInstruction_ldrsb_al_r6_r12_plus_219_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r12_minus_5_PostIndex),
    kInstruction_ldrsb_al_r9_r12_minus_5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r13_minus_90_PreIndex),
    kInstruction_ldrsb_al_r11_r13_minus_90_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r2_minus_89_PostIndex),
    kInstruction_ldrsb_al_r11_r2_minus_89_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r13_plus_130_PostIndex),
    kInstruction_ldrsb_al_r2_r13_plus_130_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r11_plus_31_PreIndex),
    kInstruction_ldrsb_al_r6_r11_plus_31_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r14_plus_177_PostIndex),
    kInstruction_ldrsb_al_r12_r14_plus_177_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_9_PreIndex),
    kInstruction_ldrsb_al_r0_r9_plus_9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r7_plus_134_PreIndex),
    kInstruction_ldrsb_al_r9_r7_plus_134_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r4_minus_1_PostIndex),
    kInstruction_ldrsb_al_r11_r4_minus_1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r4_minus_41_PreIndex),
    kInstruction_ldrsb_al_r5_r4_minus_41_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r14_plus_31_PostIndex),
    kInstruction_ldrsb_al_r4_r14_plus_31_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r2_plus_124_PostIndex),
    kInstruction_ldrsb_al_r12_r2_plus_124_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r1_minus_160_PostIndex),
    kInstruction_ldrsb_al_r8_r1_minus_160_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r3_plus_151_PostIndex),
    kInstruction_ldrsb_al_r12_r3_plus_151_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r12_plus_12_PreIndex),
    kInstruction_ldrsb_al_r11_r12_plus_12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r9_plus_75_PostIndex),
    kInstruction_ldrsb_al_r12_r9_plus_75_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_minus_80_PostIndex),
    kInstruction_ldrsb_al_r0_r9_minus_80_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r2_minus_185_PreIndex),
    kInstruction_ldrsb_al_r12_r2_minus_185_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_minus_115_PostIndex),
    kInstruction_ldrsb_al_r5_r2_minus_115_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r7_plus_82_PreIndex),
    kInstruction_ldrsb_al_r8_r7_plus_82_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r8_minus_119_PreIndex),
    kInstruction_ldrsb_al_r7_r8_minus_119_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r10_plus_38_PostIndex),
    kInstruction_ldrsb_al_r14_r10_plus_38_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r13_plus_96_PostIndex),
    kInstruction_ldrsb_al_r7_r13_plus_96_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r2_plus_253_PreIndex),
    kInstruction_ldrsb_al_r6_r2_plus_253_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r10_plus_68_PreIndex),
    kInstruction_ldrsb_al_r7_r10_plus_68_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r9_plus_182_PostIndex),
    kInstruction_ldrsb_al_r0_r9_plus_182_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r14_plus_153_PreIndex),
    kInstruction_ldrsb_al_r8_r14_plus_153_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r11_plus_69_PreIndex),
    kInstruction_ldrsb_al_r7_r11_plus_69_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r4_plus_249_PreIndex),
    kInstruction_ldrsb_al_r0_r4_plus_249_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r2_plus_65_PreIndex),
    kInstruction_ldrsb_al_r7_r2_plus_65_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r4_r10_plus_228_PostIndex),
    kInstruction_ldrsb_al_r4_r10_plus_228_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r0_minus_94_PostIndex),
    kInstruction_ldrsb_al_r5_r0_minus_94_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_minus_131_PreIndex),
    kInstruction_ldrsb_al_r10_r3_minus_131_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r14_plus_191_PreIndex),
    kInstruction_ldrsb_al_r9_r14_plus_191_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r1_minus_114_PostIndex),
    kInstruction_ldrsb_al_r3_r1_minus_114_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r4_plus_123_PreIndex),
    kInstruction_ldrsb_al_r6_r4_plus_123_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r6_minus_39_PreIndex),
    kInstruction_ldrsb_al_r12_r6_minus_39_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r11_minus_142_PostIndex),
    kInstruction_ldrsb_al_r3_r11_minus_142_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_minus_216_PostIndex),
    kInstruction_ldrsb_al_r0_r11_minus_216_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r5_minus_153_PostIndex),
    kInstruction_ldrsb_al_r9_r5_minus_153_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r1_minus_49_PostIndex),
    kInstruction_ldrsb_al_r12_r1_minus_49_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r6_plus_218_PreIndex),
    kInstruction_ldrsb_al_r9_r6_plus_218_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r6_minus_34_PostIndex),
    kInstruction_ldrsb_al_r11_r6_minus_34_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r7_plus_152_PreIndex),
    kInstruction_ldrsb_al_r10_r7_plus_152_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r5_minus_180_PostIndex),
    kInstruction_ldrsb_al_r8_r5_minus_180_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r11_plus_236_PostIndex),
    kInstruction_ldrsb_al_r0_r11_plus_236_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r2_plus_107_PostIndex),
    kInstruction_ldrsb_al_r3_r2_plus_107_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r14_plus_207_PreIndex),
    kInstruction_ldrsb_al_r6_r14_plus_207_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r11_r3_minus_146_PostIndex),
    kInstruction_ldrsb_al_r11_r3_minus_146_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r9_minus_145_PreIndex),
    kInstruction_ldrsb_al_r7_r9_minus_145_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r2_minus_30_PostIndex),
    kInstruction_ldrsb_al_r5_r2_minus_30_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r5_plus_241_PostIndex),
    kInstruction_ldrsb_al_r6_r5_plus_241_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r13_minus_218_PostIndex),
    kInstruction_ldrsb_al_r10_r13_minus_218_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r11_minus_173_PostIndex),
    kInstruction_ldrsb_al_r8_r11_minus_173_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r3_minus_44_PostIndex),
    kInstruction_ldrsb_al_r10_r3_minus_44_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r3_minus_233_PostIndex),
    kInstruction_ldrsb_al_r1_r3_minus_233_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r7_minus_227_PostIndex),
    kInstruction_ldrsb_al_r6_r7_minus_227_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r0_plus_178_PreIndex),
    kInstruction_ldrsb_al_r12_r0_plus_178_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r10_plus_134_PreIndex),
    kInstruction_ldrsb_al_r6_r10_plus_134_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r10_minus_227_PostIndex),
    kInstruction_ldrsb_al_r2_r10_minus_227_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r12_r9_minus_174_PostIndex),
    kInstruction_ldrsb_al_r12_r9_minus_174_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r6_r3_minus_109_PostIndex),
    kInstruction_ldrsb_al_r6_r3_minus_109_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r1_r6_minus_30_PostIndex),
    kInstruction_ldrsb_al_r1_r6_minus_30_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r9_plus_48_PreIndex),
    kInstruction_ldrsb_al_r2_r9_plus_48_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r13_r12_plus_4_PreIndex),
    kInstruction_ldrsb_al_r13_r12_plus_4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r8_plus_241_PostIndex),
    kInstruction_ldrsb_al_r2_r8_plus_241_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r3_plus_135_PreIndex),
    kInstruction_ldrsb_al_r14_r3_plus_135_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r3_r4_minus_161_PostIndex),
    kInstruction_ldrsb_al_r3_r4_minus_161_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r1_plus_145_PreIndex),
    kInstruction_ldrsb_al_r7_r1_plus_145_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r8_r3_plus_105_PostIndex),
    kInstruction_ldrsb_al_r8_r3_plus_105_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r8_plus_218_PreIndex),
    kInstruction_ldrsb_al_r0_r8_plus_218_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r9_r3_plus_210_PostIndex),
    kInstruction_ldrsb_al_r9_r3_plus_210_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r1_plus_228_PreIndex),
    kInstruction_ldrsb_al_r10_r1_plus_228_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r2_r0_minus_85_PostIndex),
    kInstruction_ldrsb_al_r2_r0_minus_85_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r0_r1_minus_62_PreIndex),
    kInstruction_ldrsb_al_r0_r1_minus_62_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r6_minus_150_PreIndex),
    kInstruction_ldrsb_al_r7_r6_minus_150_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r5_r3_minus_113_PreIndex),
    kInstruction_ldrsb_al_r5_r3_minus_113_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r10_r8_minus_210_PostIndex),
    kInstruction_ldrsb_al_r10_r8_minus_210_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r14_r10_plus_56_PreIndex),
    kInstruction_ldrsb_al_r14_r10_plus_56_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldrsb_al_r7_r4_plus_55_PreIndex),
    kInstruction_ldrsb_al_r7_r4_plus_55_PreIndex,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_MEMOP_IMMEDIATE_512_LDRSB_A32_H_
